<?xml version="1.0"?>

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:str="http://exslt.org/strings"
    xmlns:exsl="http://exslt.org/common"
    xmlns:regexp="http://exslt.org/regular-expressions"
    extension-element-prefixes="str regexp">
    
    <xsl:import href="xml-to-string.xsl" />
    <xsl:import href="tpl_sanitize_6100.xsl" />
    
    <xsl:output method="text"/>
    
    <xsl:template match="/">
        <xsl:variable name="content">
            <xsl:call-template name="xml-to-string">
                <xsl:with-param name="node-set" select="//div[@class='postingBody']"/>
            </xsl:call-template>
        </xsl:variable>
        
        {
        <xsl:variable name="expired">
            <xsl:value-of select="contains(//div[@class='mainBody'],'The requested ad could not be found.')"/>
        </xsl:variable>
        
        "is_expired": <xsl:value-of select="$expired"/>
        <xsl:if test="$expired='false'">
            ,
            "body": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text"><xsl:value-of select="str:replace($content,'dealercarsearch.com','')" /></xsl:with-param></xsl:call-template>",
            "descr": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text"><xsl:value-of select="//div[@class='postingBody']"/></xsl:with-param></xsl:call-template>",
            "title": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text"><xsl:value-of select="//div[@id='postingTitle']//h1"/></xsl:with-param></xsl:call-template>",
            "link": "<xsl:value-of select="//link[@rel='canonical']/@href"/>",
            
            <xsl:if test="//div[@class='mainBody']//div[contains(text(),'Location:')]">
                "place": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text"><xsl:value-of select="normalize-space(substring-after(//div[@class='mainBody']//div[contains(text(),'Location:')],'Location:'))"/></xsl:with-param></xsl:call-template>",
            </xsl:if>
            
            "posting_id":  "<xsl:value-of select="//div[@id='OtherAdsByThisUser']/@data-oid" />",
            "thumbnail_link": "<xsl:value-of select="//ul[@id='viewAdPhotoLayout']//li[1]//img/@src" />",
            
            "image_urls": [
            <xsl:for-each select="//ul[@id='viewAdPhotoLayout']//li">
                "<xsl:value-of select=".//img/@src" />"
                <xsl:if test="position()!=last()">,</xsl:if>
            </xsl:for-each>
            ],
            
            <xsl:if test="//p[@class='metaInfoDisplay']!=''">
                "map_address": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text"><xsl:value-of select="normalize-space(//p[@class='metaInfoDisplay']/text())" /></xsl:with-param></xsl:call-template>",
            </xsl:if>
            
            <xsl:if test="//p[@class='replyDisplay']!=''">
                "reply_url": "<xsl:value-of select="//p[@class='replyDisplay']/a/@href"/>",
                "mailto_info": {
                "has_captcha": true
                },
            </xsl:if>
            
            <xsl:variable name="date">
                <xsl:value-of select="normalize-space(substring-after(//div[@class='adInfo'],'Posted:'))" />
            </xsl:variable>
            "date_format":
            <xsl:choose>
                <xsl:when test="contains($date,' AM') or contains($date,' PM')">
                    "EEEE, MMMM d, yyyy h:mm a"
                </xsl:when>
                <xsl:otherwise>
                    "EEEE, d MMMM yyyy, H:mm"
                </xsl:otherwise>
            </xsl:choose>,
            "date_string": "<xsl:value-of select="$date" />"
            
        </xsl:if>
        }
    </xsl:template>
    
</xsl:stylesheet>
