<?xml version="1.0"?>

<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:str="http://exslt.org/strings"
                xmlns:regexp="http://exslt.org/regular-expressions"
                extension-element-prefixes="str regexp">

    <xsl:import href="tpl_sanitize_6100.xsl" />

    <xsl:output method="text"/>
    
    <xsl:param name="locationHref" />
    <xsl:param name="categoryHref" />
    <xsl:param name="baseURL" />
    <xsl:param name="sequence" />
    <xsl:param name="URL" />

    <!--transform CCListingsContainer-->
    <xsl:template match="/">
      {
        "listings": <xsl:call-template name="tpl_listings"/>,
        "link_next": "<xsl:value-of select="//a[@class='pagination next']/@href"/>",
        "total_count": <xsl:value-of select="count(//div[contains(@class,'cat')])"/>,
        "request_url": "<xsl:value-of select="$URL"/>"
      }
    </xsl:template>

    <!--transform CCListingData-->
    <xsl:template name="tpl_listings">
        [
        <xsl:for-each select="//div[contains(@class,'cat')]">
            {
            "posting_id": "<xsl:for-each select="regexp:match(@class, '\d+', 'i')">
                <xsl:value-of select="."/>
            </xsl:for-each>",
            "title": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select=".//a[not(@data-img)]"/></xsl:call-template>",
            "descr": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select=".//span[@class='summaryText']"/></xsl:call-template>",
            "link": "<xsl:value-of select=".//a[not(@data-img)]/@href"/>",
            "thumbnail_link": "<xsl:value-of select=".//img/@src"/>",
            "place": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="substring-before(substring-after(.//span[@class='resultsRegionLabel'],'('),')')"/></xsl:call-template>",
            "location_href": "<xsl:value-of select="$locationHref"/>",
            "category_href": "<xsl:value-of select="$categoryHref"/>",
            "grouping_info": <xsl:call-template name="tpl_grouping_info"></xsl:call-template>
            }
            <xsl:if test="position()!=last()">,</xsl:if>
        </xsl:for-each>
        ]
    </xsl:template>

    <!--transform CCListingGroupingInfo-->
    <xsl:template name="tpl_grouping_info">
        {
        <xsl:if test="preceding-sibling::div[@class='largerResults']!=''">
            "is_near_by": true,
            "group_purpose": "near_by",
        </xsl:if>
        "date_string": "<xsl:value-of select="normalize-space(preceding-sibling::div[@class='date'][1])"/>",
        "date_format": "EEE. MMM. d",
        "sequence": <xsl:value-of select="$sequence"/>
        }
    </xsl:template>

</xsl:stylesheet>
