<?xml version="1.0"?>

<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:str="http://exslt.org/strings"
                extension-element-prefixes="str">

    <xsl:import href="tpl_sanitize_6100.xsl" />

    <xsl:output method="text"/>
    <xsl:param name="sequence" />
    <xsl:param name="URL" />

    <!--transform CCListingsContainer-->
    <xsl:template match="/">
        <xsl:variable name="totalPages">
            <xsl:value-of select="//*[local-name()='paginationOutput']/*[local-name()='totalPages']"/>
        </xsl:variable>
        <xsl:variable name="pageNumber">
            <xsl:value-of select="//*[local-name()='paginationOutput']/*[local-name()='pageNumber']"/>
        </xsl:variable>
        <xsl:variable name="pageNumberFormat">
            <xsl:value-of select="'&amp;paginationInput.pageNumber='"/>
        </xsl:variable>
      {
        <xsl:choose>
          <xsl:when test="//*[local-name()='searchResult']">
              "listings": <xsl:call-template name="tpl_listings"/>,
              "total_count": <xsl:value-of select="//*[local-name()='paginationOutput']/*[local-name()='totalEntries']"/>,
          </xsl:when>
          <xsl:otherwise>
              "listings": <xsl:call-template name="tpl_favorite_listings"/>,
              "total_count": <xsl:value-of select="count(//*[local-name()='Item'])"/>,
          </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="$totalPages > $pageNumber">
            "link_next": "<xsl:value-of select="str:replace($URL,concat($pageNumberFormat,$pageNumber),concat($pageNumberFormat,$pageNumber+1))"/>",
        </xsl:if>
        "request_url": "<xsl:value-of select="$URL"/>"
      }
    </xsl:template>

    <!--transform CCListingData-->
    <xsl:template name="tpl_listings">
        [
        <xsl:for-each select="//*[local-name()='searchResult']/*[local-name()='item']">
            {
            "posting_id": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="*[local-name()='itemId']"/></xsl:call-template>",
            "title": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="*[local-name()='title']"/></xsl:call-template>",
            "link": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="*[local-name()='viewItemURL']"/></xsl:call-template>",
            "thumbnail_link": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="*[local-name()='galleryURL']"/></xsl:call-template>",
            "price": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="str:replace(concat(*[local-name()='sellingStatus']/*[local-name()='currentPrice']/@currencyId,*[local-name()='sellingStatus']/*[local-name()='currentPrice']),'USD','$')"/></xsl:call-template>",
            "place": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="*[local-name()='location']"/></xsl:call-template>",
            "grouping_info": <xsl:call-template name="tpl_grouping_info"></xsl:call-template>
            }
            <xsl:if test="position()!=last()">,</xsl:if>
        </xsl:for-each>
        ]
    </xsl:template>
    
    <!--transform CCListingData-->
    <xsl:template name="tpl_favorite_listings">
        [
        <xsl:for-each select="//*[local-name()='Item']">
            {
            "posting_id": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="*[local-name()='ItemID']"/></xsl:call-template>",
            "title": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="*[local-name()='Title']"/></xsl:call-template>",
            "link": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="*[local-name()='ViewItemURLForNaturalSearch']"/></xsl:call-template>",
            "thumbnail_link": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="*[local-name()='PictureURL']"/></xsl:call-template>",
            "price": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="str:replace(concat(*[local-name()='CurrentPrice']/@currencyID,*[local-name()='CurrentPrice']),'USD','$')"/></xsl:call-template>",
            "place": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="*[local-name()='Location']"/></xsl:call-template>",
            "is_expired": <xsl:value-of select="*[local-name()='ListingStatus'] != 'Active'"/>,
            "grouping_info": <xsl:call-template name="tpl_grouping_info"></xsl:call-template>
            }
            <xsl:if test="position()!=last()">,</xsl:if>
        </xsl:for-each>
        ]
    </xsl:template>

    <!--transform CCListingGroupingInfo-->
    <xsl:template name="tpl_grouping_info">
        {
        "group_purpose": "ebay",
        "date_string": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select=".//*[local-name()='startTime' or local-name()='StartTime']"/></xsl:call-template>",
        "date_format": "yyyy-MM-dd'T'HH:mm:ss.SSS'Z'",
        "sequence": <xsl:value-of select="$sequence"/>
        }
    </xsl:template>

</xsl:stylesheet>
