<?xml version="1.0"?>

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:str="http://exslt.org/strings"
    xmlns:exsl="http://exslt.org/common"
    xmlns:regexp="http://exslt.org/regular-expressions"
    extension-element-prefixes="str regexp">
    
    <xsl:import href="xml-to-string.xsl" />
    <xsl:import href="tpl_sanitize_6100.xsl" />
    <xsl:import href="tpl_prepend_url_6100.xsl" />
    
    <xsl:output method="text"/>

    <xsl:param name="baseURL" />
    <xsl:param name="URL" />

    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="tpl_full_img_url">
        <xsl:param name="src" />
        <xsl:if test="string-length($src)>0">
            <xsl:choose>
                <xsl:when test="contains($src,'http:')"> <!-- full image url -->
                    <xsl:value-of select="$src" />
                </xsl:when>
                <xsl:when test="contains($src,'https:')"> <!-- full image url -->
                    <xsl:value-of select="$src" />
                </xsl:when>
                <xsl:when test="contains($src,'/') = 0"> <!--this is for best-of images, which are relative to listing URL-->
                    <xsl:value-of select="regexp:replace($URL, '/([^/]*?)\.html/?', 'i', concat('/',$src))" />
                </xsl:when>
                <xsl:otherwise> <!-- otherwise some kind of relative URL - concat it with a base URL -->
                    <xsl:call-template name="tpl_prepend_href_with_base_url"><xsl:with-param name="href" select="$src"/></xsl:call-template>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:if>
    </xsl:template>

    <xsl:template match="/" name="listing_details">
        <xsl:variable name="showcontacturl">
            <xsl:value-of select="str:replace(//a[@class='show-contact']/@data-href,'__SERVICE_ID__','contactinfo')" />
        </xsl:variable>
        
        <xsl:variable name="content">
            <xsl:call-template name="xml-to-string">
                <xsl:with-param name="node-set" select="//section[@id='postingbody']/node()[not(self::figure[contains(@class,'iw')]) and not(self::div[contains(@class,'print-information')])]"/>
            </xsl:call-template>
        </xsl:variable>
        
        <!-- datetitle is needed for events category - test on it, not only on for sale category -->
        <xsl:variable name="datetitle">
            <xsl:call-template name="tpl_sanitize">
                <xsl:with-param name="text" select="//span[@class='postingtitletext']/text()[normalize-space(.) and position()=1]"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="listingtitle">
            <xsl:call-template name="tpl_sanitize">
                <xsl:with-param name="text" select="normalize-space(//span[@id='titletextonly'])"/>
            </xsl:call-template>
        </xsl:variable>
        
        {
        "body": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text"><xsl:value-of select="str:replace($content,'&quot;#&quot; class=&quot;show-contact&quot;',$showcontacturl)" /></xsl:with-param></xsl:call-template>",
        "descr": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text"><xsl:value-of select="regexp:replace($content, '&lt;/?\w+[^&lt;]*&gt;', 'g','')"/></xsl:with-param></xsl:call-template>",
        "title": "<xsl:if test="$datetitle!=''"><xsl:value-of select="$datetitle"/><xsl:value-of select="' '"/></xsl:if><xsl:value-of select="$listingtitle"/>",
        "link": "<xsl:value-of select="//link[@rel='canonical']/@href"/>",
        "price":
        <xsl:choose>
            <xsl:when test="//p[@class='attrgroup']//span[contains(text(),'age: ')]">
                "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text"><xsl:value-of select="//p[@class='attrgroup']//span[contains(text(),'age: ')]/b"/></xsl:with-param></xsl:call-template>"
            </xsl:when>
            <xsl:otherwise>
                "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text"><xsl:value-of select="//h2[@class='postingtitle']//span[@class='price']"/></xsl:with-param></xsl:call-template>"
            </xsl:otherwise>
        </xsl:choose>,
        "place": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text"><xsl:value-of select="str:replace(str:replace(//h2[@class='postingtitle']//small,'(',''),')','')"/></xsl:with-param></xsl:call-template>",
        
        <xsl:if test="//a[@class='show-contact']">
            "unhidden_contact_info_url": "<xsl:call-template name="tpl_prepend_href_with_base_url"><xsl:with-param name="href" select="$showcontacturl" /></xsl:call-template>",
        </xsl:if>
        
         <xsl:for-each select="regexp:match(string(str:replace(//link[@rel='canonical']/@href, '.html', '')),'\d+$','i')">
            "posting_id":  "<xsl:value-of select="." />",
        </xsl:for-each>
       
       <xsl:variable name="thumb">
            <xsl:call-template name="tpl_full_img_url">
                <xsl:with-param name="src" select="//div[contains(@class,'gallery')]//img/@src" />
            </xsl:call-template>
        </xsl:variable>
       "thumbnail_link": "<xsl:value-of select="str:replace($thumb, '600x450', '300x300')" />",
        
        <xsl:if test="//div[@class='reply-button-row']//button/@data-href">
            "reply_url": "<xsl:call-template name="tpl_prepend_href_with_base_url"><xsl:with-param name="href" select="str:replace(//div[@class='reply-button-row']//button/@data-href,'__SERVICE_ID__','contactinfo')" /></xsl:call-template>",
        </xsl:if>
        
        <xsl:for-each select="//form[.//input[@value='Send Note!'] and position()=last()]">
            "send_note_url": "<xsl:call-template name="tpl_prepend_href_with_base_url"><xsl:with-param name="href" select="concat('/flag?flagCode=',.//input[@name='flagCode']/@value,'&amp;postingID=',.//input[@name='postingID']/@value)" /></xsl:call-template>",
        </xsl:for-each>
        
        "image_urls": [
            <xsl:for-each select="//div[contains(@class,'gallery')]//img/@src | //div[contains(@id,'thumbs')]//a[position()>1]/@href">
                "<xsl:call-template name="tpl_full_img_url">
                <xsl:with-param name="src" select="." />
            </xsl:call-template>"
                <xsl:if test="position()!=last()">,</xsl:if>
            </xsl:for-each>
        ],
        "map_address": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text"><xsl:value-of select="//div[@class='mapaddress']" /></xsl:with-param></xsl:call-template>",
        "is_expired": <xsl:value-of select="//div[@id='userbody']/div[@class='removed']!='' or //div[@class='post-not-found']!=''"/>,
        "expired_msg": "<xsl:choose>
                    <xsl:when test="//div[@id='userbody']/div[@class='removed']!=''">
                        <xsl:call-template name="tpl_sanitize"><xsl:with-param name="text"><xsl:value-of select="//div[@id='userbody']/div[@class='removed']/h2" /></xsl:with-param></xsl:call-template>
                    </xsl:when>
                    <xsl:when test="//div[@class='post-not-found']!=''">
                        <xsl:call-template name="tpl_sanitize"><xsl:with-param name="text"><xsl:value-of select="//div[@class='post-not-found']/h1" /></xsl:with-param></xsl:call-template>
                    </xsl:when>
                </xsl:choose>",
        "notices": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text"><xsl:value-of select="//ul[@class='notices']/li" /></xsl:with-param></xsl:call-template>",
        
        <xsl:for-each select="//div[@class='mapAndAttrs'] // a[contains(@href, 'userid')] / @href">
            <xsl:for-each select="regexp:match(string(.),'userid\=\d+$','i')">
                "user_id": "<xsl:value-of select="str:replace(string(.), 'userid=', '' )" />",
            </xsl:for-each>
            
            <xsl:for-each select="regexp:match(string(.),'search\/[a-z0-9]+\?','i')">
                "top_cat_href": "<xsl:value-of select="str:replace(str:replace(string(.), '?', ''), 'search/', '')" />",
            </xsl:for-each>
        </xsl:for-each>
        
        "created_format": "yyyy-MM-dd'T'HH:mm:ssZ",
        "date_format": "yyyy-MM-dd'T'HH:mm:ssZ",
        <xsl:for-each select="//div[@class='postinginfos']//time/@datetime">
            <xsl:choose>
                <xsl:when test="position()=1">
                    "created_string": "<xsl:value-of select="." />",
                </xsl:when>
                <xsl:otherwise>
                     "date_string": "<xsl:value-of select="." />",
                </xsl:otherwise>
            </xsl:choose>
        </xsl:for-each>
        <xsl:if test="number(//div[@id='map']/@data-latitude)">
            "geo_cluster_info": {
                "latitude": <xsl:value-of select="number(//div[@id='map']/@data-latitude)" />,
                "longitude": <xsl:value-of select="number(//div[@id='map']/@data-longitude)" />
            },
        </xsl:if>
        "attributes": [
            <xsl:for-each select="//p[@class='attrgroup']//span[not(contains(a/@href,'userid'))]">
                {
                    <xsl:if test="@data-date">
                        "today_msg" : "<xsl:value-of select="@data-today_msg" />",
                        "date_string" : "<xsl:value-of select="@data-date" />",
                        "date_format": "yyyy-MM-dd",
                    </xsl:if>
                    
                    <xsl:variable name="raw_attribute">
                        <xsl:call-template name="tpl_sanitize"><xsl:with-param name="text"><xsl:value-of select="." /></xsl:with-param></xsl:call-template>
                    </xsl:variable>
                    "key" : <xsl:choose>
                        <xsl:when test="contains($raw_attribute, ':')">
                            "<xsl:value-of select="substring-before($raw_attribute, ':')" />"
                        </xsl:when>
                        <xsl:otherwise>
                            ""
                        </xsl:otherwise>
                    </xsl:choose>,
                    "value" : <xsl:choose>
                        <xsl:when test="contains($raw_attribute, ':')">
                            "<xsl:value-of select="substring-after($raw_attribute, ':')" />"
                        </xsl:when>
                        <xsl:otherwise>
                            "<xsl:value-of select="$raw_attribute" />"
                        </xsl:otherwise>
                    </xsl:choose>
                }
                <xsl:if test="position()!=last()">,</xsl:if>
            </xsl:for-each>
        ],
        "best_of_url": "<xsl:value-of select="//a[@class='bestof-link']/@href" />",
        "prohibited_url": "<xsl:value-of select="str:replace(//a[@class='bestof-link']/@href,'flagCode=9','flagCode=28')" />"
    }
    </xsl:template>

</xsl:stylesheet>
