<?xml version="1.0"?>

<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:str="http://exslt.org/strings"
                xmlns:regexp="http://exslt.org/regular-expressions"
                extension-element-prefixes="str regexp">

    <xsl:import href="tpl_prepend_url_6100.xsl" />
    <xsl:import href="tpl_sanitize_6100.xsl" />

    <xsl:output method="text"/>
    
    <xsl:param name="locationHref" />
    <xsl:param name="categoryHref" />
    <xsl:param name="baseURL" />
    <xsl:param name="sequence" />
    <xsl:param name="URL" />

    <xsl:variable name="IMAGE_BASE_URL" select="'https://images.craigslist.org/'" />
    <!--transform CCListingsContainer-->
    <xsl:template match="/">
      {
        "listings": <xsl:call-template name="tpl_listings"/>,
        <xsl:if test="//div[contains(@class, 'paginator') and not(contains(@class, 'lastpage'))]">
            "link_next": "<xsl:call-template name="tpl_prepend_href_with_base_url"><xsl:with-param name="href" select="//div[contains(@class, 'paginator') and not(contains(@class, 'lastpage'))]//a[contains(@class,'next')]/@href"/></xsl:call-template>",
        </xsl:if>
        <xsl:variable name="total" select="//span[@class='totalcount']"/>
        "total_count":
        <xsl:choose>
            <xsl:when test="$total!=''">
                <xsl:value-of select="$total"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="count(//p[@class='row'])"/>
            </xsl:otherwise>
        </xsl:choose>,
        "request_url": "<xsl:value-of select="$URL"/>",
        "has_map": <xsl:value-of select="//div[contains(@class,'search-view')]//button[@id='mapview']!=''"/>
      }
    </xsl:template>

    <!--transform CCListingData-->
    <xsl:template name="tpl_listings">
        [
        <xsl:for-each select="//li[@class='result-row']">
            {
            "posting_id": "<xsl:value-of select="@data-pid"/>",

<!-- datetitle is needed for events category - test on it, not only on for sale category -->
            <xsl:variable name="datetitle">
                <xsl:call-template name="tpl_sanitize">
                    <xsl:with-param name="text" select=".//p[@class='result-info']/text()[normalize-space(.)]"/>
                </xsl:call-template> 
            </xsl:variable>
            <xsl:variable name="listingtitle"> 
                <xsl:call-template name="tpl_sanitize">
                    <xsl:with-param name="text" select="normalize-space(.//a[contains(@class,'result-title')])"/>
                </xsl:call-template>
            </xsl:variable>

            "title": "<xsl:if test="$datetitle!=''"><xsl:value-of select="$datetitle"/><xsl:value-of select="': '"/></xsl:if><xsl:value-of select="$listingtitle"/>",
            
            "link": "<xsl:call-template name="tpl_prepend_href_with_base_url"><xsl:with-param name="href" select=".//a/@href"/></xsl:call-template>",
            "thumbnail_link": "<xsl:if test="string(a/@data-ids)!=''">
                <xsl:for-each select="regexp:match(regexp:replace(string(a/@data-ids),'\d+:','i',''), '\w+', 'i')">
                    <xsl:value-of select="$IMAGE_BASE_URL"/><xsl:value-of select="."/><xsl:value-of select="'_300x300.jpg'" />
                </xsl:for-each>
            </xsl:if>",
            "price": "<xsl:value-of select=".//span[@class='result-price'] | .//span[@class='result-age']"/>",
            <xsl:variable name="cleanPlace">
                <xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select=".//span[@class='result-hood']"/></xsl:call-template>
            </xsl:variable>
            "place": "<xsl:value-of select="str:replace(str:replace($cleanPlace,'(',''),')','')"/>",
            "location_href": "<xsl:value-of select="$locationHref"/>",
            "category_href": "<xsl:value-of select="$categoryHref"/>",
            "pic_tag": <xsl:value-of select="contains(.//span[@class='result-tags'],'pic')" />,
            "img_tag": <xsl:value-of select="contains(.//span[@class='result-tags'],'img')" />,
            "map_tag": <xsl:value-of select="contains(.//span[@class='result-tags'],'map')" />,
            "grouping_info": <xsl:call-template name="tpl_grouping_info"></xsl:call-template>
            }
            <xsl:if test="position()!=last()">,</xsl:if>
        </xsl:for-each>
        ]
    </xsl:template>

    <!--transform CCListingGroupingInfo-->
    <xsl:variable name="currentDate">
        <xsl:if test="regexp:test(//span[contains(@class,'cur_day')],'.* \w{3} \w{3}[ ]+\d+','i')">
            <xsl:for-each select="regexp:match(string(//span[contains(@class,'cur_day')]),'\w{3} \w{3}[ ]+\d+','i')">
                <xsl:value-of select="."/>
            </xsl:for-each>
        </xsl:if>
    </xsl:variable>
    <xsl:variable name="ignoreTitleDuplicates">
        <xsl:value-of select="$categoryHref='gms' or $categoryHref='eve'"/>
    </xsl:variable>
    <xsl:template name="tpl_grouping_info">
        {
        "ignore_title_duplicates": <xsl:value-of select="$ignoreTitleDuplicates"/>,
        
        <xsl:if test="preceding-sibling::h4[contains(@class,'nearby')]!=''">
            "is_near_by": true,
            "group_purpose": "near_by",
        </xsl:if>
        
        <xsl:choose>
            <xsl:when test="$currentDate!=''">
                "date_string": "<xsl:value-of select="$currentDate"/>",
                "date_format": "EEE MMM d"
            </xsl:when>
            <xsl:when test="regexp:test(string(preceding-sibling::h4[@class='ban' and position()=1]/span),'.* \w{3} \w{3}[ ]+\d+','i')">
                "date_string": "<xsl:for-each select="regexp:match(string(preceding-sibling::h4[@class='ban' and position()=1]/span),'\w{3} \w{3}[ ]+\d+','i')">
                    <xsl:value-of select="."/>
                </xsl:for-each>",
                "date_format": "EEE MMM d",
                "ignore_date_sorting": 1
            </xsl:when>
            <xsl:when test="contains(.//time/@datetime, 'T')">
                "date_string": "<xsl:value-of select="substring-before(.//time/@datetime,'T')"/>",
                "date_format": "yyyy-MM-dd"
            </xsl:when>
            <xsl:when test="contains(.//time/@datetime, ' ')">
                "date_string": "<xsl:value-of select="substring-before(.//time/@datetime,' ')"/>",
                "date_format": "yyyy-MM-dd"
            </xsl:when>
            <xsl:otherwise>
                "date_string": "<xsl:value-of select="substring-before(.//time,' ')"/>",
                "date_format": "yyyy-MM-dd"
            </xsl:otherwise>
        </xsl:choose>,
        "sequence": <xsl:value-of select="$sequence"/>
        }
    </xsl:template>

</xsl:stylesheet>
