<?xml version="1.0"?>

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:exsl="http://exslt.org/common"
    xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
    xmlns:enc="http://purl.oclc.org/net/rss_2.0/enc#"
    xmlns:ev="http://purl.org/rss/1.0/modules/event/"
    xmlns:dcterms="http://purl.org/dc/terms/"
    xmlns:syn="http://purl.org/rss/1.0/modules/syndication/"
    xmlns:dc="http://purl.org/dc/elements/1.1/"
    xmlns:str="http://exslt.org/strings"
    xmlns:regexp="http://exslt.org/regular-expressions"
    extension-element-prefixes="str regexp">

    <xsl:import href="tpl_sanitize_6100.xsl" />

    <xsl:output method="text"/>

    <xsl:param name="locationHref" />
    <xsl:param name="categoryHref" />
    <xsl:param name="sequence" />
    <xsl:param name="URL" />
    
    <!--transform CCListingsContainer-->
    <xsl:template match="/">
        {
        <xsl:variable name="total" select="count(//*[local-name()='item'])"/>
        "listings": <xsl:call-template name="tpl_listings"/>,
        "link_next":
        "<xsl:choose>
            <xsl:when test="$total>0">
                <xsl:choose>
                    <xsl:when test="regexp:test(string($URL),'.*&amp;s=.*$','i')">
                        <xsl:variable name="next">
                            <xsl:value-of select="'&amp;s='"/><xsl:value-of select="number(substring-after($URL,'&amp;s='))+$total"/>
                        </xsl:variable>
                        <xsl:value-of select="regexp:replace(string($URL),'&amp;s=.*$','i',$next)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$URL"/><xsl:value-of select="'&amp;s='"/><xsl:value-of select="$total"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
        </xsl:choose>",
        "total_count": <xsl:value-of select="$total"/>,
        "has_map": 1
        }
    </xsl:template>
    
    <!--transform CCListingData-->
    <xsl:template name="tpl_listings">
        [
        <xsl:for-each select="//*[local-name()='item']">
            {
            <xsl:variable name="cleanTitle">
                <xsl:if test="ev:startdate!='' and ev:enddate!=''">
                    <xsl:call-template name="tpl_parse_event_date">
                        <xsl:with-param name="date" select="ev:startdate"/>
                    </xsl:call-template><xsl:value-of select="'-'"/>
                    <xsl:call-template name="tpl_parse_event_date">
                        <xsl:with-param name="date" select="ev:enddate"/>
                    </xsl:call-template><xsl:value-of select="': '"/>
                </xsl:if>
                <xsl:call-template name="tpl_sanitize">
                    <xsl:with-param name="text"><xsl:value-of select="substring-before(substring-after(regexp:replace(string(.),'&lt;sup.*&gt;','i',''), '&lt;![CDATA['), ']]>')"/></xsl:with-param>
                </xsl:call-template>
            </xsl:variable>
            "posting_id": "<xsl:for-each select="regexp:match(string(dc:source),'/\d+\.html','i')">
                <xsl:value-of select="substring-after(str:replace(.,'.html',''),'/')"/>
            </xsl:for-each>",
            "title": "<xsl:value-of select="$cleanTitle"/>",
            "descr": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="string(./*[local-name()='description'])"/></xsl:call-template>",
            "link": "<xsl:value-of select="dc:source"/>",
            "thumbnail_link": "<xsl:value-of select="enc:enclosure/@resource"/>",
            "price":
            "<xsl:choose>
                <xsl:when test="regexp:test(string($cleanTitle),'.* \d+yr','i')">
                    <xsl:for-each select="regexp:match($cleanTitle,' \d+yr','i')">
                        <xsl:value-of select="str:replace(str:replace(.,' ',''),'yr','')"/>
                    </xsl:for-each>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:for-each select="regexp:match(string($cleanTitle),'[\$\£\€]\d+','gi')">
                        <xsl:if test="position()=last()"><xsl:value-of select="."/></xsl:if>
                    </xsl:for-each>
                </xsl:otherwise>
            </xsl:choose>",
            "place": "<xsl:for-each select="regexp:match(string($cleanTitle),'\([^\(^\).]+\)(?!.*\([^\(^\).]+\))','i')">
                <xsl:value-of select="str:replace(str:replace(.,'(',''),')','')"/>
            </xsl:for-each>",
            "date_format": "yyyy-MM-dd'T'HH:mm:ssZ",
            "date_string": "<xsl:value-of select="dc:date"/>",
            "location_href": "<xsl:value-of select="$locationHref"/>",
            "category_href": "<xsl:value-of select="$categoryHref"/>",
            "grouping_info": <xsl:call-template name="tpl_grouping_info"></xsl:call-template>
            }
            <xsl:if test="position()!=last()">,</xsl:if>
        </xsl:for-each>
        ]
    </xsl:template>
    
    <xsl:template name="tpl_parse_event_date">
        <xsl:param name="date"/>
        <xsl:for-each select="str:split($date,'-')">
            <xsl:if test="position()!=1">
                <xsl:value-of select="number(.)"/>
                <xsl:if test="position()!=last()">/</xsl:if>
            </xsl:if>
        </xsl:for-each>
    </xsl:template>
    
    <!--transform CCListingGroupingInfo-->
    <xsl:variable name="ignoreTitleDuplicates">
        <xsl:value-of select="$categoryHref='gms' or $categoryHref='eve'"/>
    </xsl:variable>
    <xsl:template name="tpl_grouping_info">
        {
        "ignore_title_duplicates": <xsl:value-of select="$ignoreTitleDuplicates"/>,
        "date_string": "<xsl:value-of select="substring-before(dc:date,'T')"/>",
        "date_format": "yyyy-MM-dd",
        "sequence": <xsl:value-of select="$sequence"/>
        }
    </xsl:template>
    
</xsl:stylesheet>

