<?xml version="1.0"?>

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:str="http://exslt.org/strings"
    xmlns:exsl="http://exslt.org/common"
    xmlns:regexp="http://exslt.org/regular-expressions"
    extension-element-prefixes="str regexp">
    
    <xsl:import href="tpl_sanitize_6100.xsl" />
    
    <xsl:output method="text"/>
    
    <!--transform CCPostManageAccountData-->
    <xsl:template match="/">
        {
        "posted_listings": <xsl:call-template name="tpl_posted_listings"/>,
        "action_url": "<xsl:value-of select="//section[@class='body']/form/@action[1]"/>",
        "post_categories": <xsl:call-template name="tpl_select"><xsl:with-param name="name" select="'filter_cat'" /><xsl:with-param name="augmentation" select="'Category'" /></xsl:call-template>,
        "post_months": <xsl:call-template name="tpl_select"><xsl:with-param name="name" select="'filter_date'" /><xsl:with-param name="augmentation" select="'Month'" /></xsl:call-template>,
        "post_days": <xsl:call-template name="tpl_select"><xsl:with-param name="name" select="'filter_day'" /><xsl:with-param name="augmentation" select="'Day'" /></xsl:call-template>,
        "post_terms": <xsl:call-template name="tpl_terms"/>,
        "post_actives": <xsl:call-template name="tpl_actives"/>,
        "post_pages": <xsl:call-template name="tpl_pages"/>,
        
        <xsl:variable name="total" select="//legend[@id='paginator1']/small/b[3]"/>
        "total":
        <xsl:choose>
            <xsl:when test="$total!=''">
                <xsl:value-of select="$total"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="count(//fieldset[@id='paginator']//tr[not (@class='headers')])"/>
            </xsl:otherwise>
        </xsl:choose>
        }
    </xsl:template>
    
    <!--transform CCPostedListingData-->
    <xsl:template name="tpl_posted_listings">
        [
        <xsl:for-each select="//fieldset[@id='paginator']//tr[not (@class='headers')]">
            {
            <xsl:call-template name="tpl_color"/>,
            "posting_title": "<xsl:call-template name="tpl_sanitize">
                <xsl:with-param name="text" select="./td[contains(@class,'title')]"/>
            </xsl:call-template>",
            "posted_date": "<xsl:call-template name="tpl_sanitize">
                <xsl:with-param name="text" select="./td[contains(@class,'dates')]"/>
            </xsl:call-template>",
            "posting_id": "<xsl:call-template name="tpl_sanitize">
                <xsl:with-param name="text" select="./td[contains(@class,'postingID')]"/>
            </xsl:call-template>",
            <xsl:variable name="area" select="./td[contains(@class,'areacat')]/b"/>
            "area": "<xsl:call-template name="tpl_sanitize">
                <xsl:with-param name="text" select="$area"/>
            </xsl:call-template>",
            "category": "<xsl:call-template name="tpl_sanitize">
                <xsl:with-param name="text" select="substring-after(./td[contains(@class,'areacat')],$area)"/>
            </xsl:call-template>",
            <xsl:variable name="link" select="./td[contains(@class,'title')]/a/@href"/>
            "link": "<xsl:value-of select="$link"/>",
            "post_form_datas": <xsl:call-template name="tpl_form_datas"><xsl:with-param name="link" select="$link" /></xsl:call-template>
            }
            <xsl:if test="position()!=last()">,</xsl:if>
        </xsl:for-each>
        ]
    </xsl:template>
    
    <!--transform CCPostAccountColorData-->
    <xsl:template name="tpl_color">
        "color_data": {
        <xsl:for-each select="./td[contains(@class,'status')]">
            <xsl:variable name="color" select="@class"/>
            "display_name": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="./small"/></xsl:call-template>",
            "color_name":
            <xsl:choose>
                <xsl:when test="$color='status active'">
                    "#90ee90"
                </xsl:when>
                <xsl:when test="$color='status deleted'">
                    "#add8e6"
                </xsl:when>
                <xsl:when test="$color='status removed'">
                    "#ffc0cb"
                </xsl:when>
                <xsl:when test="$color='status expired'">
                    "#cdcdcd"
                </xsl:when>
                <xsl:otherwise>
                    "#ffffff"
                </xsl:otherwise>
            </xsl:choose>
        </xsl:for-each>
        }
    </xsl:template>
    
    <!--transform CCPostFormData-->
    <xsl:template name="tpl_form_datas">
        <xsl:param name="link" />
        [
        <xsl:if test="$link != ''">
            {
                "method": "GET",
                "action_url": "<xsl:value-of select="$link"/>",
                "fields": [
                    {
                    "value": "Open",
                    "name": ""
                    }
                ]
            }
            <xsl:if test="./td[contains(@class,'buttons')]//form">
                ,
            </xsl:if>
        </xsl:if>
        <xsl:for-each select="./td[contains(@class,'buttons')]//form">
            {
            "method": "<xsl:value-of select="@method"/>",
            <xsl:choose>
                <xsl:when test="./input[@value='repost']">
                    "action_tag": "repost",
                </xsl:when>
                <xsl:when test="./input[@value='delete']">
                    "action_tag": "remove_post",
                </xsl:when>
                <xsl:when test="./input[@value='undelete']">
                    "action_tag": "undelete_post",
                </xsl:when>
            </xsl:choose>
            
            "action_url": "<xsl:value-of select="@action"/>",
            "fields": [
            <xsl:for-each select="./input">
                {
                "value": "<xsl:value-of select="@value"/>",
                "name": "<xsl:value-of select="@name"/>"
                }
                <xsl:if test="position()!=last()">,</xsl:if>
            </xsl:for-each>
            ]
            }
            <xsl:if test="position()!=last()">,</xsl:if>
        </xsl:for-each>
        ]
    </xsl:template>
    
    <!--transform CCPostFieldData-->
    <xsl:template name="tpl_select">
        <xsl:param name="name" />
        <xsl:param name="augmentation" />
        <xsl:variable name="selectedCount" select="count(//form[1]//table[@id='searchtable']//select[@name=$name]/option/@selected)"/>
        [
        <xsl:for-each select="//form[1]//table[@id='searchtable']//select[@name=$name]/option">
            {
            "display_name": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="."/></xsl:call-template>",
            "value": "<xsl:value-of select="@value"/>",
            "name": "<xsl:value-of select="$name"/>",
            "augmentation_name": "<xsl:value-of select="$augmentation"/>",
            "is_checked":
            <xsl:choose>
                <xsl:when test="position()=1 and $selectedCount=0">
                    1
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="count(@selected)"/>
                </xsl:otherwise>
            </xsl:choose>
            }
            <xsl:if test="position()!=last()">,</xsl:if>
        </xsl:for-each>
        ]
    </xsl:template>
    
    <xsl:template name="tpl_actives">
        [
        <xsl:for-each select="//form[1]//legend[@id='searchlegend']/span[2]/span/b | //form[1]//legend[@id='searchlegend']/span[2]/button[@value!='']">
            {
            "display_name": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="."/></xsl:call-template>",
            
            "value": <xsl:choose>
                <xsl:when test="@value!=''">
                    "<xsl:value-of select="@value"/>"
                </xsl:when>
                <xsl:when test="//input[@name='filter_active']/@value">
                    "<xsl:value-of select="//input[@name='filter_active']/@value"/>"
                </xsl:when>
                <xsl:otherwise>
                    "0"
                </xsl:otherwise>
            </xsl:choose>,
            
            "name": "filter_active",
            "is_checked": <xsl:value-of select="not(@class)"/>
            }
            <xsl:if test="position()!=last()">,</xsl:if>
        </xsl:for-each>
        ]
    </xsl:template>
    
    <xsl:template name="tpl_pages">
        [
        <xsl:for-each select="//legend[@id='paginator1']/b | //legend[@id='paginator1']/a">
            {
            "display_name": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="."/></xsl:call-template>",
            "value": "<xsl:value-of select="."/>",
            "name": "filter_page",
            "is_checked": <xsl:value-of select="not(@href)"/>
            }
            <xsl:if test="position()!=last()">,</xsl:if>
        </xsl:for-each>
        ]
    </xsl:template>
    
    <xsl:template name="tpl_terms">
        <xsl:for-each select="//input[@id='terms' and position()=1]">
            {
            "value": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="@value"/></xsl:call-template>",
            "name": "<xsl:value-of select="@name"/>",
            "placeholder": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="@placeholder"/></xsl:call-template>"
            }
        </xsl:for-each>
    </xsl:template>
    
</xsl:stylesheet>

