<?xml version="1.0"?>

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:str="http://exslt.org/strings"
    xmlns:exsl="http://exslt.org/common"
    extension-element-prefixes="str">
    
    <xsl:import href="tpl_sanitize_6100.xsl" />
    
    <xsl:output method="text"/>
    
    <!--transform CCPostManageAccountData-->
    <xsl:template match="/">
        {
        "saved_searches": <xsl:call-template name="tpl_saved_searches"/>
        }
    </xsl:template>
    
    <!--transform CCSavedSearchData-->
    <xsl:template name="tpl_saved_searches">
        [
        <xsl:for-each select="//table[@id='savedsearchlist']/tbody/tr">
            {
            <xsl:for-each select="./td">
                <xsl:if test="position()=1">
                    "save_form_data": {
                        "method": "<xsl:value-of select="form/@method"/>",
                        "action_url": "<xsl:value-of select="concat('https://accounts.craigslist.org',form/@action)"/>",
                        "fields": [
                        <xsl:for-each select="form//input">
                            {
                            <xsl:choose>
                                <xsl:when test="@name = 'subName'">
                                    "augmentation_name" : "sub_name",
                                </xsl:when>
                                <xsl:when test="@name = 'subNotify'">
                                    "augmentation_name" : "sub_notify",
                                </xsl:when>
                            </xsl:choose>
                            "type": "<xsl:value-of select="@type"/>",
                            <xsl:if test="@type = 'checkbox'">
                                "is_checked" : <xsl:choose>
                                    <xsl:when test="@checked"> true </xsl:when>
                                    <xsl:otherwise> false </xsl:otherwise>
                                </xsl:choose>,
                            </xsl:if>
                            "value": "<xsl:value-of select="@value"/>",
                            "name": "<xsl:value-of select="@name"/>"
                            }
                            <xsl:if test="position()!=last()">,</xsl:if>
                        </xsl:for-each>
                        ]
                    },
                </xsl:if>
                <xsl:if test="position()=2">
                    "created_string": "<xsl:value-of select="time/@datetime"/>",
                    "created_format": "YYYY-MM-DD'T'HH:mm:ssZ",
                </xsl:if>
                <xsl:if test="position()=3">
                    "name": "<xsl:call-template name="tpl_sanitize">
                        <xsl:with-param name="text" select="text()"/>
                    </xsl:call-template>",
                </xsl:if>
                <xsl:if test="position()=4">
                    "url": "<xsl:value-of select="a/@href"/>",
                    "params": [
                    <xsl:choose>
                        <xsl:when test="a/strong">
                            <xsl:for-each select="a/strong">
                                {"<xsl:call-template name="tpl_sanitize">
                                    <xsl:with-param name="text" select="str:replace(.,':','')"/>
                                </xsl:call-template>":
                                "<xsl:call-template name="tpl_sanitize">
                                    <xsl:with-param name="text" select="str:replace(following-sibling::text(),',','')"/>
                                </xsl:call-template>"}
                                <xsl:if test="position()!=last()">,</xsl:if>
                            </xsl:for-each>
                        </xsl:when>
                        <xsl:otherwise>
                            {"":"<xsl:call-template name="tpl_sanitize">
                                <xsl:with-param name="text" select="a"/>
                            </xsl:call-template>"}
                        </xsl:otherwise>
                    </xsl:choose>
                    ],
                </xsl:if>
                <xsl:if test="position()=5">
                    "hits_count": 0, <!--need to perfom https://accounts.craigslist.org/savesearch/counts request-->
                    "hits_id" : "<xsl:value-of select="span/@id"/>",
                    "hits_count_key": "count",
                    "hits_id_key": "id",
                </xsl:if>
                <xsl:if test="position()=6">
                        "post_form_datas": [
                        {
                            "method": "GET",
                            "action_tag": "open_save_search",
                            "top_title": "Open"
                        },
                        {
                            "action_url": "<xsl:value-of select="concat('https://accounts.craigslist.org',a/@href)"/>",
                            "action_tag": "edit_save_search",
                            "top_title": "<xsl:call-template name="tpl_sanitize">
                                <xsl:with-param name="text" select="a/button/text()"/>
                            </xsl:call-template>"
                        },
                        {
                            "method": "<xsl:value-of select="form/@method"/>",
                            "action_tag": "delete_save_search",
                            "action_url": "<xsl:value-of select="concat('https://accounts.craigslist.org',form/@action)"/>",
                            "top_title": "<xsl:call-template name="tpl_sanitize">
                                <xsl:with-param name="text" select="form/button/text()"/>
                            </xsl:call-template>",
                            "fields": [
                            <xsl:for-each select="form/input">
                                {
                                "type": "<xsl:value-of select="@type"/>",
                                "value": "<xsl:value-of select="@value"/>",
                                "name": "<xsl:value-of select="@name"/>"
                                }
                                <xsl:if test="position()!=last()">,</xsl:if>
                            </xsl:for-each>
                            ]
                        }
                    ]
                </xsl:if>
            </xsl:for-each>
            }
            <xsl:if test="position()!=last()">,</xsl:if>
        </xsl:for-each>
        ]
    </xsl:template>
    
</xsl:stylesheet>

