<?xml version="1.0"?>

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:str="http://exslt.org/strings"
    xmlns:exsl="http://exslt.org/common"
    xmlns:regexp="http://exslt.org/regular-expressions"
    extension-element-prefixes="str regexp">
    
    <xsl:import href="tpl_sanitize_6100.xsl" />
    <xsl:import href="tpl_post_common.xsl" />
    
    <xsl:output method="text"/>
    
    <xsl:variable name="dirty_title">
        <xsl:choose>
            <xsl:when test="//form[@id='mapprobform']">
                <xsl:value-of select="//form[@id='mapprobform']" />
            </xsl:when>
            <xsl:when test="//p[@class='formnote']">
                <xsl:value-of select="//p[@class='formnote']" />
            </xsl:when>
            <xsl:when test="//form//blockquote//b">
                <xsl:value-of select="//form//blockquote//b" />
            </xsl:when>
            <xsl:when test="//form//b">
                <xsl:value-of select="//form//b" />
            </xsl:when>
            <xsl:when test="//p">
                <xsl:value-of select="//p" />
            </xsl:when>
        </xsl:choose>
    </xsl:variable>
    
    <xsl:variable name="top_title">
        <xsl:value-of select="str:replace(str:replace($dirty_title, '(see prohibited list before posting.)', ''), '(see prohibited list and recall information before posting.)', '')" />
    </xsl:variable>

    <xsl:template name="post_input_radio_definition">
        <xsl:param name="enclosed_input" />
        {
            "name" : "<xsl:value-of select=".//input[@type='radio']/@name"/>",
            "type" : "radio",
            <xsl:variable name="display_name">
                <xsl:choose>
                    <xsl:when test=".//span[@class='right-side']"><xsl:value-of select=".//span[@class='right-side']" /></xsl:when>
                    <xsl:when test=".//label"><xsl:value-of select=".//label" /></xsl:when>
                    <xsl:otherwise><xsl:value-of select="." /></xsl:otherwise>
                </xsl:choose>
            </xsl:variable>
            "display_name" : "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="$display_name" /></xsl:call-template>",
            "value" : "<xsl:value-of select=".//input[@type='radio']/@value"/>",
            "is_checked" : <xsl:choose>
                <xsl:when test=".//input[@type='radio']/@checked">
                    true
                </xsl:when>
                <xsl:otherwise>
                    false
                </xsl:otherwise>
            </xsl:choose>,
            "price": <xsl:choose>
                <xsl:when test="regexp:test(.//span[@class='option-label-addendum']/small,'.*\d+ per post.*', 'i')">
                    <xsl:for-each select="regexp:match(.//span[@class='option-label-addendum']/small, '\d+', 'i')">
                        <xsl:value-of select="." />
                    </xsl:for-each>
                </xsl:when>
                <xsl:otherwise>0</xsl:otherwise>
            </xsl:choose>
        },
    </xsl:template>

    <!--transform CCPostFormData-->
    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="post_categories" match="/">
    {
        <xsl:call-template name="post_single_form_definition"/>,
        <xsl:call-template name="post_breadcrumbs"/>,
        "top_title" : "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="$top_title" /></xsl:call-template>",
        "message" : "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="//form[@class='picker']//p[@class='formnote']" /></xsl:call-template>",
        
        "fields" : [
            <xsl:choose>
                <xsl:when test="//form//label//input[@type='radio']">
                    <xsl:for-each select="//form//label[not(contains(@class,'category-select')) and not(contains(@class,'variant-radio'))]">
                        <xsl:call-template name="post_input_radio_definition">
                            <xsl:with-param name="enclosed_input" select="." />
                        </xsl:call-template>
                    </xsl:for-each>
                </xsl:when>
                <xsl:when test="//form//input[@type='checkbox']">
                    <xsl:for-each select="//form//label[not(contains(@class,'category-select')) and not(contains(@class,'variant-radio'))]">
                        {
                            "display_name" : "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select=".//span[@class='label']"/></xsl:call-template>",
                            "price": <xsl:choose>
                                <xsl:when test=".//input/@data-price">
                                    <xsl:value-of select=".//input/@data-price" />
                                </xsl:when>
                                <xsl:otherwise>0</xsl:otherwise>
                            </xsl:choose>,
                            <xsl:call-template name="post_input_checkbox_definition">
                                <xsl:with-param name="input" select=".//input[@type='checkbox']" />
                            </xsl:call-template>
                        },
                    </xsl:for-each>
                 </xsl:when>
            </xsl:choose>
            <xsl:for-each select="//form//input[@type='hidden']">
            {
                <xsl:call-template name="post_input_base_definition">
                    <xsl:with-param name="input" select="." />
                </xsl:call-template>
            },
            </xsl:for-each>
            {
                "name" : "<xsl:value-of select="//form//button//@name" />",
                "value" : "<xsl:value-of select="//form//button//@value"/>",
                "type" : "submit"
            }
        ]
    }

    </xsl:template>
    
</xsl:stylesheet>
