<?xml version="1.0"?>

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:str="http://exslt.org/strings"
    xmlns:exsl="http://exslt.org/common"
    xmlns:regexp="http://exslt.org/regular-expressions"
    extension-element-prefixes="str regexp">

    <xsl:import href="post_categories.xsl" />
    <xsl:import href="post_map.xsl" />
    <xsl:import href="post_confirm_3.xsl" />
    <xsl:import href="post_form_2.9.xsl" />
    <xsl:import href="post_imageupload_2.5.xsl" />
    <xsl:import href="post_login.xsl" />
    <xsl:import href="post_signup.xsl" />
    <xsl:import href="post_password_reset.xsl" />
    <xsl:import href="post_thanks_panel.xsl" />
    <xsl:import href="post_personalsseeking.xsl" />
    <xsl:import href="tpl_sanitize_6100.xsl" />

    <xsl:output method="text"/>

    <xsl:param name="URL" />
    <xsl:param name="platform" />
    <xsl:param name="appVersionCode" />
    <xsl:param name="appFlavor" />

    <xsl:variable name="picker"> <xsl:value-of select="'|picker|'"/> </xsl:variable>
    <xsl:variable name="mapinfo"> <xsl:value-of select="'|mapinfo|'"/> </xsl:variable>
    <xsl:variable name="postingForm"> <xsl:value-of select="'|postingForm|'"/> </xsl:variable>
    <xsl:variable name="uploader"> <xsl:value-of select="'|uploader|'"/> </xsl:variable>
    <xsl:variable name="previewButtons"> <xsl:value-of select="'|previewButtons|'"/> </xsl:variable>
    <xsl:variable name="signup"> <xsl:value-of select="'|signup|'"/> </xsl:variable>
    <xsl:variable name="thankspanel"> <xsl:value-of select="'|thankspanel|'"/> </xsl:variable>
    <xsl:variable name="login"> <xsl:value-of select="'|login|'"/> </xsl:variable>
    <xsl:variable name="forgetPassword"> <xsl:value-of select="'|forgetPassword|'"/> </xsl:variable>
    <xsl:variable name="bchead"> <xsl:value-of select="'|bchead|'"/> </xsl:variable>
    <xsl:variable name="tabcontainer"> <xsl:value-of select="'|tabcontainer|'"/> </xsl:variable>
    <xsl:variable name="flava"> <xsl:value-of select="'|flava|'"/> </xsl:variable>
    <xsl:variable name="managestatus"> <xsl:value-of select="'|managestatus|'"/> </xsl:variable>
    <xsl:variable name="termsofuse"> <xsl:value-of select="'|termsofuse|'"/> </xsl:variable>

    <!--transform CCPostResultContainer-->
    <xsl:template match="/">
        {
        <xsl:variable name="result">
            <xsl:call-template name="result_match"/>
        </xsl:variable>
        <xsl:variable name="content">
            <xsl:call-template name="xml-to-string"> <xsl:with-param name="node-set" select="."/> </xsl:call-template>
        </xsl:variable>

        "html_string" : "<xsl:if test="$platform='ios'">
            <xsl:call-template name="tpl_sanitize"><xsl:with-param name="text"><xsl:value-of select="$content"/></xsl:with-param></xsl:call-template>
        </xsl:if>",

        <xsl:choose>
            <xsl:when test="//div[@id='map']">
                "js": "post_map",
            </xsl:when>
        </xsl:choose>

        "url": "<xsl:value-of select="$URL"/>",
        <xsl:choose>
            <xsl:when test="$result=$picker">
                "type" : "PostCategories",
                "model" : <xsl:call-template name="post_categories"/>
            </xsl:when>
            <xsl:when test="$result=concat($picker,$flava)">
                "type" : "PostPersonalsSeekingType",
                "model" : <xsl:call-template name="post_personalsseeking"/>
            </xsl:when>
            <xsl:when test="$result=$postingForm">
                "type" : "PostForm",
                "model" : <xsl:call-template name="post_form"/>
            </xsl:when>
            <xsl:when test="$result=$mapinfo">
                "type" : "PostMapForm",
                "model" : <xsl:call-template name="post_map_info"/>
            </xsl:when>
            <xsl:when test="$result=$uploader">
                "type" : "PostImageUpload",
                "model" : <xsl:call-template name="post_imageupload"/>
            </xsl:when>
            <xsl:when test="$result=$previewButtons">
                "type" : "PostConfirmForm",
                "model" : <xsl:call-template name="post_confirm"/>
            </xsl:when>
            <xsl:when test="$result=$login">
                "type" : "PostLoginForm",
                "model" : <xsl:call-template name="post_login"/>
            </xsl:when>
            <xsl:when test="$result=$signup">
                "type" : "PostSignupForm",
                "model" : <xsl:call-template name="post_signup"/>
            </xsl:when>
            <xsl:when test="$result=$thankspanel">
                "type" : "PostThanksPanel",
                "model" : <xsl:call-template name="post_thx_panel"/>
            </xsl:when>
            <xsl:when test="$result=$forgetPassword">
                "type" : "PostForgetPasswordForm",
                "model" : <xsl:call-template name="post_pwd_reset"/>
            </xsl:when>
            <xsl:when test="$result=concat($bchead,$tabcontainer)">
                "type" : "PostLoggedIn",
                "model" : <xsl:call-template name="post_login"/>
            </xsl:when>
            <xsl:when test="$result=$managestatus">
                "type" : "ManageAccountPostings"
            </xsl:when>
            <xsl:when test="$result=$termsofuse">
                "type" : "TermsOfUse"
            </xsl:when>
            <xsl:otherwise>
                "type" : "PostWebView"
            </xsl:otherwise>
        </xsl:choose>
        }
    </xsl:template>

    <xsl:template name="result_match">

        <xsl:if test="//form[contains(@class,'picker')]"><xsl:value-of select="$picker"/></xsl:if>

        <xsl:if test="//form[@id='postingForm'] and //button[@value='continue'] and not(//table[@id='postingInvoice'])"><xsl:value-of select="$postingForm"/></xsl:if>

        <xsl:if test="//div[@id='uploader']//form"><xsl:value-of select="$uploader"/></xsl:if>

        <xsl:if test="//section[@id='previewButtons']"><xsl:value-of select="$previewButtons"/></xsl:if>

        <xsl:if test="//form[contains(@action,'/signup')] and not(//form[@class='loginform'])">  <xsl:value-of select="$signup"/> </xsl:if>

        <xsl:if test="//div[contains(@class, 'password-reset-box')]"> <xsl:value-of select="$forgetPassword"/> </xsl:if>

        <xsl:if test="//form[@class='loginform']"><xsl:value-of select="$login"/></xsl:if>

        <xsl:if test="//header[@class='account-header']//span[@id='ef']"><xsl:value-of select="$bchead"/></xsl:if>

        <xsl:if test="//div[@class='tabcontainer']/span[@class='tab']/b"><xsl:value-of select="$tabcontainer"/></xsl:if>

        <xsl:if test="//table//fieldset/label[@for='w2']"><xsl:value-of select="$flava"/></xsl:if>
        
        <xsl:if test="//div[@class='account-thanks-panel']"> <xsl:value-of select="$thankspanel"/> </xsl:if>
        
        <!--iOS-->
        <xsl:if test="$platform='ios'">
            <xsl:if test="//form[@id='leafletForm']"><xsl:value-of select="$mapinfo"/></xsl:if>
        </xsl:if>
        
        <!--Android-->
        <xsl:if test="$platform='android'">

            <xsl:variable name="androidAppVersionCode"> <xsl:value-of select="number($appVersionCode)"/> </xsl:variable>

            <xsl:if test="$appFlavor = '' and $androidAppVersionCode &gt; 156">
                <xsl:if test="//div[@class='managestatus']"> <xsl:value-of select="$managestatus"/> </xsl:if>
            </xsl:if>

            <xsl:if test="($appFlavor = 'googleMaterial' and $androidAppVersionCode &gt; 208) or
                ($appFlavor = 'amazonMaterial' and $androidAppVersionCode &gt; 389) or
                ($appFlavor = 'googleStuffMaterial')">
                <xsl:if test="//div[@class='managestatus']"> <xsl:value-of select="$managestatus"/> </xsl:if>
                <xsl:if test="//form[@action='/login/tou']"> <xsl:value-of select="$termsofuse"/> </xsl:if>
            </xsl:if>

            <xsl:if test="($appFlavor = 'googleMaterial' and $androidAppVersionCode &gt; 226) or
                ($appFlavor = 'googleThirdPartyMaterial' and $androidAppVersionCode &gt; 226) or
                ($appFlavor = 'googleStuffMaterial' and $androidAppVersionCode &gt; 10) or
                ($appFlavor = 'googleStuffThirdPartyMaterial' and $androidAppVersionCode &gt; 10) or
                ($appFlavor = 'amazonMaterial' and $androidAppVersionCode &gt; 407)">
                <xsl:if test="//form[@id='leafletForm']"><xsl:value-of select="$mapinfo"/></xsl:if>
            </xsl:if>
        </xsl:if>

    </xsl:template>

</xsl:stylesheet>
