<?xml version="1.0"?>

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:str="http://exslt.org/strings"
    xmlns:exsl="http://exslt.org/common"
    extension-element-prefixes="str">
    
    <xsl:import href="tpl_sanitize_6100.xsl" />
    <xsl:import href="tpl_post_common.xsl" />
    <xsl:import href="xml-to-string.xsl" />

    <xsl:import href="post_form_fees_and_licensure_2.9.xsl" />
    <xsl:import href="post_form_contact_info_2.9.xsl" />
    <xsl:import href="post_form_common_posting_info_2.9.xsl" />
    <xsl:import href="post_form_posting_details_2.9.xsl" />
    <xsl:import href="post_form_event_features_2.9.xsl" />
    <xsl:import href="post_form_license_2.9.xsl" />
    <xsl:import href="post_form_location_info_2.9.xsl" />
    <xsl:import href="post_form_remuneration_2.9.xsl" />
    <xsl:import href="post_form_legalese_2.9.xsl" />
    <xsl:import href="post_form_resumes_availability.xsl" />
    <xsl:import href="post_form_copyright_assignment.xsl" />
    
    <xsl:output method="text"/>
    
    <xsl:variable name="error">
        <xsl:call-template name="xml-to-string">
            <xsl:with-param name="node-set" select="//form//span[@class='err']//parent::div[@class='highlight']"/>
        </xsl:call-template>
    </xsl:variable>

    <xsl:variable name="message">
        <xsl:call-template name="xml-to-string">
            <xsl:with-param name="node-set" select="//aside[@id='housingBlurb']"/>
        </xsl:call-template>
    </xsl:variable>

    <xsl:variable name="content">
        <xsl:call-template name="xml-to-string">
            <xsl:with-param name="node-set" select="." />
        </xsl:call-template>
    </xsl:variable>

    <!--transform CCPostFormData-->
    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="post_form" match="/">
        {
        <xsl:call-template name="post_single_form_definition"/>,
        <xsl:call-template name="post_breadcrumbs"/>,

        <xsl:if test="string-length($error) > 0">
            "error": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="$error"/></xsl:call-template>",
        </xsl:if>

        <xsl:if test="string-length($message) > 0">
            "message": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="$message"/></xsl:call-template>",
        </xsl:if>
        
        "fields" : [

        <!-- Hidden fields -->
        <xsl:for-each select="//form//input[@type='hidden' and @name != 'FromEMail' and @name != 'discard']">
            {
            <xsl:call-template name="post_input_base_definition">
                <xsl:with-param name="input" select="."/>
            </xsl:call-template>
            },
        </xsl:for-each>
        
        <!-- Contact info -->
        <xsl:variable name='contact_info'><xsl:call-template name="post_contact_info"/></xsl:variable>
        <xsl:if test="string-length($contact_info)">
            <xsl:copy-of select="$contact_info"/>,
        </xsl:if>
        
        <!-- Common posting info -->
        <xsl:variable name='common_posting_info'><xsl:call-template name="post_common_posting_info"/></xsl:variable>
        <xsl:if test="string-length($common_posting_info)">
            <xsl:copy-of select="$common_posting_info"/>,
        </xsl:if>
        
        <!-- Resumes availability -->
        <xsl:variable name='resumes_availability'><xsl:call-template name="post_resumes_availability"/></xsl:variable>
        <xsl:if test="string-length($resumes_availability)">
            <xsl:copy-of select="$resumes_availability"/>,
        </xsl:if>

        <!-- Posting Details -->
        <xsl:variable name='posting_details'><xsl:call-template name="post_posting_details"/></xsl:variable>
        <xsl:if test="string-length($posting_details)">
            <xsl:copy-of select="$posting_details"/>,
        </xsl:if>
        
        <!-- Event Features -->
        <xsl:variable name='event_features'><xsl:call-template name="post_event_features"/></xsl:variable>
        <xsl:if test="string-length($event_features)">
            <xsl:copy-of select="$event_features"/>,
        </xsl:if>
        
        <!-- Fees and Licensure -->
        <xsl:variable name='fees_and_licensure'><xsl:call-template name="post_fees_and_licensure"/></xsl:variable>
        <xsl:if test="string-length($fees_and_licensure)">
            <xsl:copy-of select="$fees_and_licensure"/>,
        </xsl:if>
        
        <!-- Event Features -->
        <xsl:variable name='copyright_assignment'><xsl:call-template name="post_copyright_assignment"/></xsl:variable>
        <xsl:if test="string-length($copyright_assignment)">
            <xsl:copy-of select="$copyright_assignment"/>,
        </xsl:if>
        
        <!-- License -->
        <xsl:variable name='license'><xsl:call-template name="post_license"/></xsl:variable>
        <xsl:if test="string-length($license)">
            <xsl:copy-of select="$license"/>,
        </xsl:if>
        
        <!-- location info -->
        <xsl:variable name='location_info'><xsl:call-template name="post_location_info"/></xsl:variable>
        <xsl:if test="string-length($location_info)">
            <xsl:copy-of select="$location_info"/>,
        </xsl:if>
        
        <!-- Remuneration -->
        <xsl:variable name='remuneration'><xsl:call-template name="post_remuneration"/></xsl:variable>
        <xsl:if test="string-length($remuneration)">
            <xsl:copy-of select="$remuneration"/>,
        </xsl:if>
        
        <!-- Terms -->
        {
        "display_name" : "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="//form//input[@class='contact_ok' or @class='disability_ok']//following-sibling::div/span"/></xsl:call-template>",
        <xsl:call-template name="post_input_checkbox_definition">
            <xsl:with-param name="input" select="//form//input[@class='contact_ok' or @class='disability_ok']"/>
        </xsl:call-template>
        },

        <!-- Submit -->
        {
        "name" : "<xsl:value-of select="//form//button//@name" />",
        "value" : "<xsl:value-of select="//form//button//@value"/>",
        "type" : "submit"
        }
        
        <!-- Copy assign -->
        <xsl:variable name='legalese'><xsl:call-template name="post_legalese"/></xsl:variable>
        <xsl:if test="string-length($legalese)">
            <xsl:copy-of select="$legalese"/>,
        </xsl:if>

        ]
        
        }
    </xsl:template>
    
</xsl:stylesheet>
