<?xml version="1.0"?>

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:str="http://exslt.org/strings"
    xmlns:exsl="http://exslt.org/common"
    xmlns:regexp="http://exslt.org/regular-expressions"
    extension-element-prefixes="str regexp">
    
    <xsl:import href="tpl_sanitize_6100.xsl" />
    <xsl:import href="tpl_post_common.xsl" />
    <xsl:import href="xml-to-string.xsl" />
    <xsl:import href="post_helpful_details_6150.xsl" />
    
    <xsl:output method="text"/>
    
    <xsl:variable name="error">
        <xsl:call-template name="xml-to-string">
            <xsl:with-param name="node-set" select="//form//span[@class='err']//parent::div[@class='highlight']"/>
        </xsl:call-template>
    </xsl:variable>
    
    <xsl:variable name="content">
        <xsl:call-template name="xml-to-string">
            <xsl:with-param name="node-set" select="." />
        </xsl:call-template>
    </xsl:variable>
    
    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="input_remuneration" >
        {
        "display_name" : "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select="//form//input[@name='remuneration']//parent::label//span[1]" /><xsl:with-param name="name" select="'remuneration'" /></xsl:call-template>",
        "name" : "remuneration",
        "value" : "<xsl:value-of select="//form//input[@name='remuneration']/@value"/>",
        "type" : "text",
        "required": true,
        "placeholder": <xsl:choose>
            <xsl:when test="//form//input[@name='remuneration']/@placeholder">
                "<xsl:value-of select="//form//input[@name='remuneration']/@placeholder"/>"
            </xsl:when>
            <xsl:otherwise>
                "<xsl:value-of select="//span[@id='compdet']"/>"
            </xsl:otherwise>
        </xsl:choose>
        
        
        }
    </xsl:template>
    
    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="input_remuneration_type" >
        <xsl:call-template name="post_radio_definition">
            <xsl:with-param name="radio_x_path" select="//form//input[@name='remuneration_type']"/>
            <xsl:with-param name="radio_names" select="//form//input[@name='remuneration_type']//parent::label"/>
        </xsl:call-template>
    </xsl:template>
    
    <!--transform CCPostFormData-->
    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="post_form" match="/">
        {
        <xsl:call-template name="post_single_form_definition"/>,
        <xsl:call-template name="post_breadcrumbs"/>,
        
        <xsl:if test="string-length($error) > 0">
            "error": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="$error"/></xsl:call-template>",
        </xsl:if>
        
        "fields" : [
        <xsl:for-each select="//form//input[@type='hidden' and @name != 'FromEMail' and @name != 'ConfirmEMail' and @name != 'discard']">
            {
            <xsl:call-template name="post_input_base_definition">
                <xsl:with-param name="input" select="."/>
            </xsl:call-template>
            },
        </xsl:for-each>
        
        <!-- Fees and Licensure -->
        <xsl:variable name='fees_fieldset' select="//form//fieldset[contains(@class,'housing-pre-warning')]" />
        <xsl:if test="$fees_fieldset">
            {
            "type" : "fieldset",
            "display_name": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="$fees_fieldset/legend"/></xsl:call-template>",
            "fields": [
            <xsl:for-each select="$fees_fieldset//input">
                {
                "display_name" : "<xsl:value-of select="str:replace(@name,'_',' ')"/>",
                "name" : "<xsl:value-of select="@name"/>",
                "value" : "<xsl:value-of select="@value"/>",
                <xsl:if test="@value=''">
                    "autofillable" : true,
                </xsl:if>
                <xsl:if test="preceding-sibling::span[@class='err' and position()=1]">
                    "is_error" : true,
                </xsl:if>
                "required": true,
                "type" : "<xsl:value-of select="@type"/>"
                }
                <xsl:if test="position()!=last()">,</xsl:if>
            </xsl:for-each>
            ]
            },
        </xsl:if>
        
        <!-- Contact info -->
        {
        "type" : "fieldset",
        "display_name": "<xsl:value-of select="//form//fieldset[legend/text()='contact info']//legend"/>",
        "fields": [
        <xsl:choose>
            <xsl:when test="//form//fieldset[legend/text()='contact info']//input[@name='FromEMail']">
                {
                "name" : "FromEMail",
                "value" : <xsl:choose>
                    <xsl:when test="//form//fieldset[legend/text()='contact info']//input[@name='FromEMail']/@value != 'Your email address'">
                        "<xsl:value-of select="//form//fieldset[legend/text()='contact info']//input[@name='FromEMail']/@value"/>",
                    </xsl:when>
                    <xsl:otherwise>
                        "",
                        "placeholder": "Your email address",
                    </xsl:otherwise>
                </xsl:choose>
                "type": "text",
                <xsl:choose>
                    <xsl:when test="//form//fieldset[legend/text()='contact info']//input[@name='FromEMail']/@type='hidden'">
                        "disabled": true,
                    </xsl:when>
                    <xsl:when test="//form//fieldset[legend/text()='contact info']//input[@name='FromEMail']/@value=''">
                        "autofillable" : true,
                    </xsl:when>
                </xsl:choose>
                "display_name": "from email",
                "required": true
                }
                <xsl:if test="//form//fieldset[legend/text()='contact info']//input[@name='ConfirmEMail']">
                    ,
                    {
                    "name" : "ConfirmEMail",
                    "value" : <xsl:choose>
                        <xsl:when test="contains(//form//fieldset[legend/text()='contact info']//input[@name='ConfirmEMail']/@value, 'email address again')">
                            "",
                            "placeholder": "Type email address again",
                        </xsl:when>
                        <xsl:otherwise>
                            "<xsl:value-of select="//form//fieldset[legend/text()='contact info']//input[@name='ConfirmEMail']/@value"/>",
                            
                        </xsl:otherwise>
                    </xsl:choose>
                    "type": "text",
                    <xsl:choose>
                        <xsl:when test="//form//fieldset[legend/text()='contact info']//input[@name='ConfirmEMail']/@type='hidden'">
                            "disabled": true,
                        </xsl:when>
                        <xsl:when test="//form//fieldset[legend/text()='contact info']//input[@name='ConfirmEMail']/@value=''">
                            "autofillable" : true,
                        </xsl:when>
                    </xsl:choose>
                    "display_name": "confirm email",
                    "required": true
                    }
                </xsl:if>

            </xsl:when>
        </xsl:choose>
        
        <xsl:if test="//form//fieldset[legend/text()='contact info']//input[@type='radio']">
            ,
            <xsl:call-template name="post_radio_definition">
                <xsl:with-param name="radio_x_path" select="//form//fieldset[legend/text()='contact info']//input[@type='radio']" />
                <xsl:with-param name="radio_names" select="//form//fieldset[legend/text()='contact info']//input[@type='radio']//parent::label"/>
            </xsl:call-template>
        </xsl:if>
        
        
        <xsl:for-each select="//form//fieldset[legend/text()='contact info']//input[@type='checkbox']">
            ,                    {
            "display_name" : "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select="parent::label//preceding-sibling::div//span" /><xsl:with-param name="name" select="@name" /></xsl:call-template>",
            <xsl:call-template name="post_input_checkbox_definition">
                <xsl:with-param name="input" select="."/>
            </xsl:call-template>
            }
        </xsl:for-each>
        
        <xsl:for-each select="//form//fieldset[legend/text()='contact info']//input[@type='text' and @name!='FromEMail' and @name!='ConfirmEMail']">
            ,
            {
            "display_name" : "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select="parent::label//preceding-sibling::div//span" /><xsl:with-param name="name" select="@name" /></xsl:call-template>",
            <xsl:call-template name="post_input_base_definition">
                <xsl:with-param name="input" select="."/>
            </xsl:call-template>
            }
        </xsl:for-each>
        ]
        },
        
        <!-- Common posting info -->
        {
        "display_name" : "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select="//form//input[@name='PostingTitle']/parent::label//preceding-sibling::div//span" /><xsl:with-param name="name" select="PostingTitle" /></xsl:call-template>",
        <xsl:call-template name="post_input_base_definition">
            <xsl:with-param name="input" select="//form//input[@name='PostingTitle']"/>
        </xsl:call-template>,
        "is_post_form_title": true,
        "is_error": <xsl:choose>
            <xsl:when test="contains(//form//input[@name='PostingTitle']//parent::label//parent::label/@class, 'err')">
                true
            </xsl:when>
            <xsl:otherwise>
                false
            </xsl:otherwise>
        </xsl:choose>,
        "required": true
        },
        <xsl:if test="//form//input[@name='price']">
            {
            "display_name" : "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select="//form//input[@name='price']/parent::label//preceding-sibling::div//span" /><xsl:with-param name="name" select="price" /></xsl:call-template>",
            <xsl:choose>
                <xsl:when test="$platform='ios'">
                    <xsl:call-template name="post_input_number_definition">
                        <xsl:with-param name="input" select="//form//input[@name='price']"/>
                    </xsl:call-template>,
                </xsl:when>
                <xsl:otherwise>
                    "name": "<xsl:value-of select="//form//input[@name='price']/@name" />",
                    "value": "<xsl:value-of select="//form//input[@name='price']/@value"/>",
                    "type": "text",
                </xsl:otherwise>
            </xsl:choose>
            "is_error": <xsl:choose>
                <xsl:when test="contains(//form//input[@name='price']//parent::label//parent::label/@class, 'err')">
                    true
                </xsl:when>
                <xsl:otherwise>
                    false
                </xsl:otherwise>
            </xsl:choose>,
            "required": true
            },
        </xsl:if>
        <xsl:if test="//form//input[@name='GeographicArea']">
            {
            "display_name" : "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select="//form//input[@name='GeographicArea']/parent::label//preceding-sibling::div//span" /><xsl:with-param name="name" select="GeographicArea" /></xsl:call-template>",
            <xsl:call-template name="post_input_base_definition">
                <xsl:with-param name="input" select="//form//input[@name='GeographicArea']"/>
            </xsl:call-template>
            },
        </xsl:if>
        {
        "display_name" : "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select="//form//input[@name='postal' and not(contains(@class, 'disabled')) and not(contains(@class, 'nreq'))]/parent::label//preceding-sibling::div//span" /><xsl:with-param name="name" select="postal" /></xsl:call-template>",
        <xsl:call-template name="post_input_base_definition">
            <xsl:with-param name="input" select="//form//input[@name='postal' and not(contains(@class, 'disabled')) and not(contains(@class, 'nreq'))]"/>
        </xsl:call-template>,
        "is_error": <xsl:choose>
            <xsl:when test="contains(//form//input[@name='postal' and not(contains(@class, 'disabled')) and not(contains(@class, 'nreq'))]//parent::label//parent::label/@class, 'err')">
                true
            </xsl:when>
            <xsl:otherwise>
                false
            </xsl:otherwise>
        </xsl:choose>,
        "required": true
        },
        
        {
        "display_name" : "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select="//form//textarea[@name='PostingBody']//preceding-sibling::div//span" /><xsl:with-param name="name" select="PostingBody" /></xsl:call-template>",
        "name" : "PostingBody",
        "value" : "<xsl:call-template name="tpl_sanitize_textarea"><xsl:with-param name="text" select="//form//textarea[@name='PostingBody']"/></xsl:call-template>",
        "type" : "textarea",
        "is_error": <xsl:choose>
            <xsl:when test="contains(//form//textarea[@name='PostingBody']//parent::label/@class, 'err')">
                true
            </xsl:when>
            <xsl:otherwise>
                false
            </xsl:otherwise>
        </xsl:choose>,
        "required": true
        },
        
        <xsl:for-each select="//fieldset">
            <xsl:choose>
                <!-- posting details -->
                <xsl:when test="./legend = 'posting details'">
                    {
                    "type" : "fieldset",
                    "display_name": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="./legend"/></xsl:call-template>",
                    "fields": [
                    <xsl:for-each select=".//select | .//input[@name != 'postal' and @name != 'price' and not(contains(@name,'event_'))]">
                        <xsl:choose>
                            
                            <xsl:when test="@name = 'eventStart' or @name = 'moveinDate'">
                                {
                                "display_name": "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select=".//parent::label//preceding-sibling::div//span"/></xsl:call-template>",
                                "type": "calendar",
                                "required": <xsl:choose>
                                    <xsl:when test="contains(.//parent::label//parent::label/@class, 'req')">
                                        true
                                    </xsl:when>
                                    <xsl:otherwise>
                                        false
                                    </xsl:otherwise>
                                </xsl:choose>,
                                "placeholder": "select date",
                                "is_error": <xsl:choose>
                                    <xsl:when test="contains(.//parent::label//parent::label/@class, 'err')">
                                        true
                                    </xsl:when>
                                    <xsl:otherwise>
                                        false
                                    </xsl:otherwise>
                                </xsl:choose>,
                                "name": "<xsl:value-of select="@name"/>",
                                "value": "<xsl:value-of select="@value"/>",
                                "min": 0,
                                "max": 6,
                                "format": "yyyy-MM-dd"
                                }<xsl:if test="position()!=last()">,</xsl:if>
                            </xsl:when>
                            
                            <xsl:when test="@name != '' and .//option">
                                
                                {
                                "display_name" : "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select="parent::label//preceding-sibling::div//span" /><xsl:with-param name="name" select="@name" /></xsl:call-template>",
                                "name" : "<xsl:value-of select="@name"/>",
                                "required": <xsl:choose>
                                    <xsl:when test="contains(.//parent::label//parent::label/@class, 'req') or contains(.//parent::label//parent::label/@class, 'err')">
                                        true
                                    </xsl:when>
                                    <xsl:otherwise>
                                        false
                                    </xsl:otherwise>
                                </xsl:choose>,
                                "type" : "select",
                                "value":  <xsl:choose>
                                    <xsl:when test="./option[@selected]/@value">
                                        "<xsl:value-of select="./option[@selected]/@value"/>",
                                    </xsl:when>
                                    <xsl:otherwise>
                                        "<xsl:value-of select="./option[1]/@value"/>",
                                    </xsl:otherwise>
                                </xsl:choose>
                                
                                
                                "is_error": <xsl:choose>
                                    <xsl:when test="contains(.//parent::label/@class, 'err')">
                                        true
                                    </xsl:when>
                                    <xsl:otherwise>
                                        false
                                    </xsl:otherwise>
                                </xsl:choose>,
                                "options" : [
                                <xsl:for-each select=".//option">
                                    {
                                    "display_name" : "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="."/></xsl:call-template>",
                                    "value" : "<xsl:value-of select="@value"/>",
                                    "is_selected" : <xsl:choose>
                                        <xsl:when test="@selected">
                                            true
                                        </xsl:when>
                                        <xsl:when test="not(parent::select/option[@selected]) and position()=1">
                                            true
                                        </xsl:when>
                                        <xsl:otherwise>
                                            false
                                        </xsl:otherwise>
                                    </xsl:choose>
                                    }
                                    <xsl:if test="position()!=last()">,</xsl:if>
                                </xsl:for-each>
                                ]
                                }
                                <xsl:if test="position()!=last()">,</xsl:if>
                            </xsl:when>
                            
                            <xsl:otherwise>
                                {
                                "display_name" :
                                        "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select="parent::label//preceding-sibling::div//span" /><xsl:with-param name="name" select="@name" /></xsl:call-template>",
                                "name" : "<xsl:value-of select="@name" />",
                                "value" : "<xsl:value-of select="@value"/>",
                                <xsl:if test="@type = 'number'">
                                    "min" : <xsl:choose>
                                        <xsl:when test="@min">
                                            <xsl:value-of select="@min"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            0
                                        </xsl:otherwise>
                                    </xsl:choose>,
                                    "max" : <xsl:choose>
                                        <xsl:when test="@max">
                                            <xsl:value-of select="@max"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            2147483647
                                        </xsl:otherwise>
                                    </xsl:choose>,
                                </xsl:if>
                                "type" : <xsl:choose>
                                    <xsl:when test="@type = 'checkbox'">
                                        "<xsl:value-of select="@type"/>",
                                        "is_checked" : <xsl:choose>
                                            <xsl:when test="@checked">
                                                true
                                            </xsl:when>
                                            <xsl:otherwise>
                                                false
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:when>
                                    <xsl:when test="@type">
                                        "<xsl:value-of select="@type"/>"
                                    </xsl:when>
                                    <xsl:otherwise>
                                        "text"
                                        <xsl:if test="@placeholder">
                                            ,
                                            "placeholder": "<xsl:value-of select="@placeholder"/>"
                                        </xsl:if>
                                    </xsl:otherwise>
                                </xsl:choose>,
                                "is_error": <xsl:choose>
                                    <xsl:when test="contains(.//parent::label//parent::label/@class, 'err')">
                                        true
                                    </xsl:when>
                                    <xsl:otherwise>
                                        false
                                    </xsl:otherwise>
                                </xsl:choose>,
                                "required": <xsl:choose>
                                    <xsl:when test="contains(.//parent::label//parent::label/@class, 'req') or contains(.//parent::label//parent::label/@class, 'err')">
                                        true
                                    </xsl:when>
                                    <xsl:otherwise>
                                        false
                                    </xsl:otherwise>
                                </xsl:choose>
                                }
                                <xsl:if test="position()!=last()">,</xsl:if>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:for-each>
                    
                    ]
                    },
                </xsl:when>
                
                <xsl:when test="./legend ='helpful details'">
                    <xsl:call-template name="post_helpful_details"></xsl:call-template>,
                </xsl:when>
            </xsl:choose>
        </xsl:for-each>
        
        <xsl:if test="//form//input[contains(@name, 'event_')]">
            {
            "type" : "fieldset",
            "display_name": "event features (choose up to three)",
            
            "fields": [
            <xsl:for-each select="//form//input[(not(@type) or @type!='hidden') and contains(@name, 'event_')]">
                {
                "display_name" : "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select="parent::label" /><xsl:with-param name="name" select="@name" /></xsl:call-template>",
                "name" : "<xsl:value-of select="@name" />",
                "value" : "<xsl:value-of select="@value"/>",
                "is_checked": <xsl:choose>
                    <xsl:when test="@checked">
                        true
                    </xsl:when>
                    <xsl:otherwise>
                        false
                    </xsl:otherwise>
                </xsl:choose>,
                "type" : "checkbox",
                "limit_group_name": "event_features",
                "limit_group_value": 3
                }
                <xsl:if test="position()!=last()">,</xsl:if>
            </xsl:for-each>
            ]
            },
        </xsl:if>
        
        <xsl:if test="//form//input[@name='has_license']">
            {
            "type" : "fieldset",
            "fields": [
            <xsl:call-template name="post_radio_definition">
                <xsl:with-param name="radio_x_path" select="//form//input[@name='has_license']"/>
                <xsl:with-param name="radio_names" select="//form//input[@name='has_license']//parent::label"/>
            </xsl:call-template>,
            {
            "display_name" : "license info",
            <xsl:call-template name="post_input_base_definition">
                <xsl:with-param name="input" select="//form//input[@name='license_info']"/>
            </xsl:call-template>,
            "required": true,
            "placeholder": "<xsl:value-of select="//span[@id='licdet']" />"
            }
            ]
            },
        </xsl:if>
        
        <!-- location info -->
        <xsl:if test="//form//fieldset[contains(@class,'location-info')]">
            {
            "type" : "fieldset",
            "display_name": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="//form//fieldset[contains(@class,'location-info')]/legend"/></xsl:call-template>",
            "fields": [
            <xsl:for-each select="//form//fieldset[contains(@class,'location-info')]//input">
                {
                "display_name" : "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="parent::label//preceding-sibling::div//span"/></xsl:call-template>",
                "name" : "<xsl:value-of select="@name" />",
                "value" : "<xsl:value-of select="@value"/>",
                <xsl:if test="@value=''">
                    "autofillable" : true,
                </xsl:if>
                "type" : "<xsl:value-of select="@type"/>"
                }
                <xsl:if test="position()!=last()">,</xsl:if>
            </xsl:for-each>
            ]
            },
        </xsl:if>
        
        <xsl:choose>
            <xsl:when test="//form//input[@name='remuneration'] and //form//input[@name='remuneration_type']">
                {
                "type" : "fieldset",
                "fields": [
                <!-- compensation -->
                <xsl:call-template name="input_remuneration"></xsl:call-template>,
                <!-- remuneration_type (pay/no pay) -->
                <xsl:call-template name="input_remuneration_type"></xsl:call-template>
                ]
                },
            </xsl:when>
            <xsl:when test="//form//input[@name='remuneration']">
                <xsl:call-template name="input_remuneration"></xsl:call-template>,
            </xsl:when>
            <xsl:when test="//form//input[@name='remuneration_type']">
                <xsl:call-template name="input_remuneration_type"></xsl:call-template>,
            </xsl:when>
        </xsl:choose>
        
        
        <!-- Terms -->
        {
        "display_name" : "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="//form//input[@class='contact_ok' or @class='disability_ok']//following-sibling::div/span"/></xsl:call-template>",
        <xsl:call-template name="post_input_checkbox_definition">
            <xsl:with-param name="input" select="//form//input[@class='contact_ok' or @class='disability_ok']"/>
        </xsl:call-template>
        },
        {
        "name" : "<xsl:value-of select="//form//button//@name" />",
        "value" : "<xsl:value-of select="//form//button//@value"/>",
        "type" : "submit"
        }
        
        <!-- Copy assign -->
        <xsl:if test="//form//div[@class='copy_legalese']">
            , {
            "type" : "fieldset",
            "fields": [
            <xsl:for-each select="//form//div[@class='copy_legalese']//input">
                {
                "display_name" : "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="parent::label//preceding-sibling::div//span"/></xsl:call-template>",
                "name" : "<xsl:value-of select="@name" />",
                "value" : "<xsl:value-of select="@value"/>",
                <xsl:if test="@value=''">
                    "autofillable" : true,
                </xsl:if>
                "type" :  "<xsl:value-of select="@type"/>"
                }
                <xsl:if test="position()!=last()">,</xsl:if>
            </xsl:for-each>
            ]
            }
        </xsl:if>
        ]
        
        }
    </xsl:template>
    
</xsl:stylesheet>
