<?xml version="1.0"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

    <xsl:import href="tpl_sanitize_6100.xsl" />
    <xsl:import href="tpl_post_common.xsl" />

    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="post_common_posting_info" >

        <!-- Posting Title -->
        <xsl:variable name='posting_title_input' select="//form//input[@name='PostingTitle']" />
        {
        "display_name" : "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select="$posting_title_input/parent::label//preceding-sibling::div//span" /><xsl:with-param name="name" select="PostingTitle" /></xsl:call-template>",
        <xsl:call-template name="post_input_base_definition">
            <xsl:with-param name="input" select="$posting_title_input"/>
        </xsl:call-template>,
        "is_post_form_title": true,
        <xsl:call-template name="post_field_is_error"> <xsl:with-param name="input" select="$posting_title_input"/> </xsl:call-template>,
        <xsl:call-template name="post_field_required"> <xsl:with-param name="input" select="$posting_title_input"/> </xsl:call-template>
        },

        <!-- Price -->
        <xsl:variable name='price_input' select="//form//input[@name='price']" />
        <xsl:if test="$price_input">
            {
            "display_name" : "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select="$price_input/parent::label//preceding-sibling::div//span" /><xsl:with-param name="name" select="price" /></xsl:call-template>",
            <xsl:choose>
                <xsl:when test="$platform='ios'">
                    <xsl:call-template name="post_input_number_definition">
                        <xsl:with-param name="input" select="$price_input"/>
                    </xsl:call-template>,
                </xsl:when>
                <xsl:otherwise>
                    "name": "<xsl:value-of select="$price_input/@name" />",
                    "value": "<xsl:value-of select="$price_input/@value"/>",
                    "type": "text",
                </xsl:otherwise>
            </xsl:choose>
            <xsl:call-template name="post_field_is_error"> <xsl:with-param name="input" select="$price_input"/> </xsl:call-template>,
            <xsl:call-template name="post_field_required"> <xsl:with-param name="input" select="$price_input"/> </xsl:call-template>
            },
        </xsl:if>

        <!-- Geographic Area -->
        <xsl:variable name='geographic_area_input' select="//form//input[@name='GeographicArea']" />
        <xsl:if test="$geographic_area_input">
            {
            "display_name" : "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select="$geographic_area_input/parent::label//preceding-sibling::div//span" /><xsl:with-param name="name" select="GeographicArea" /></xsl:call-template>",
            <xsl:call-template name="post_field_is_error"> <xsl:with-param name="input" select="$geographic_area_input"/> </xsl:call-template>,
            <xsl:call-template name="post_field_required"> <xsl:with-param name="input" select="$geographic_area_input"/> </xsl:call-template>,
            <xsl:call-template name="post_input_base_definition">
                <xsl:with-param name="input" select="$geographic_area_input"/>
            </xsl:call-template>
            },
        </xsl:if>

        <!-- Postal Code -->
        <xsl:variable name='postal_input' select="//form//input[@name='postal' and not(contains(@class, 'disabled')) and not(contains(@class, 'nreq'))]" />
        {
        "display_name" : "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select="$postal_input/parent::label//preceding-sibling::div//span" /><xsl:with-param name="name" select="postal" /></xsl:call-template>",
        <xsl:call-template name="post_input_base_definition">
            <xsl:with-param name="input" select="$postal_input"/>
        </xsl:call-template>,
        <xsl:call-template name="post_field_is_error"> <xsl:with-param name="input" select="$postal_input"/> </xsl:call-template>,
        <xsl:call-template name="post_field_required"> <xsl:with-param name="input" select="$postal_input"/> </xsl:call-template>
        },
        
        <!-- Body -->
        <xsl:variable name='posting_body_input' select="//form//textarea[@name='PostingBody']" />
        {
        "display_name" : "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select="$posting_body_input//preceding-sibling::div//span" /><xsl:with-param name="name" select="PostingBody" /></xsl:call-template>",
        "name" : "PostingBody",
        "value" : "<xsl:call-template name="tpl_sanitize_textarea"><xsl:with-param name="text" select="$posting_body_input"/></xsl:call-template>",
        "type" : "textarea",
        <xsl:call-template name="post_field_is_error"> <xsl:with-param name="input" select="$posting_body_input"/> </xsl:call-template>,
        <xsl:call-template name="post_field_required"> <xsl:with-param name="input" select="$posting_body_input"/> </xsl:call-template>
        }
        
    </xsl:template>

</xsl:stylesheet>
