<?xml version="1.0"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

    <xsl:import href="tpl_sanitize_6100.xsl" />
    <xsl:import href="tpl_post_common.xsl" />
    <xsl:import href="post_helpful_details_6150.xsl" />

    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="post_posting_details" >
        
        <xsl:for-each select="//fieldset">
            <xsl:choose>
                <!-- posting details -->
                <xsl:when test="./legend = 'posting details'">
                    {
                    "type" : "fieldset",
                    "display_name": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="./legend"/></xsl:call-template>",
                    "fields": [
                    <xsl:for-each select=".//select | .//input[@name != 'postal' and @name != 'price' and not(contains(@name,'event_'))]">
                        <xsl:choose>
                            
                            <!-- date fields -->
                            <xsl:when test="@name = 'eventStart' or @name = 'movein_date'">
                                {
                                "display_name": "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select=".//parent::label//preceding-sibling::div//span"/></xsl:call-template>",
                                "type": "calendar",
                                "placeholder": "select date",
                                <xsl:call-template name="post_field_required"> <xsl:with-param name="input" select="."/> </xsl:call-template>,
                                <xsl:call-template name="post_field_is_error"> <xsl:with-param name="input" select="."/> </xsl:call-template>,
                                "name": "<xsl:value-of select="@name"/>",
                                "value": "<xsl:value-of select="@value"/>",
                                "min": 0,
                                "max": 6,
                                "format": "yyyy-MM-dd"
                                }<xsl:if test="position()!=last()">,</xsl:if>
                            </xsl:when>
                            
                            <!-- options fields -->
                            <xsl:when test="@name != '' and .//option">
                                
                                {
                                "display_name" : "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select="parent::label//preceding-sibling::div//span" /><xsl:with-param name="name" select="@name" /></xsl:call-template>",
                                "name" : "<xsl:value-of select="@name"/>",
                                "type" : "select",
                                "value":  <xsl:choose>
                                    <xsl:when test="./option[@selected]/@value">
                                        "<xsl:value-of select="./option[@selected]/@value"/>",
                                    </xsl:when>
                                    <xsl:otherwise>
                                        "<xsl:value-of select="./option[1]/@value"/>",
                                    </xsl:otherwise>
                                </xsl:choose>
                                
                                <xsl:call-template name="post_field_required"> <xsl:with-param name="input" select="."/> </xsl:call-template>,
                                <xsl:call-template name="post_field_is_error"> <xsl:with-param name="input" select="."/> </xsl:call-template>,
                                "options" : [
                                <xsl:for-each select=".//option">
                                    {
                                    "display_name" : "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="."/></xsl:call-template>",
                                    "value" : "<xsl:value-of select="@value"/>",
                                    "is_selected" : <xsl:choose>
                                        <xsl:when test="@selected">
                                            true
                                        </xsl:when>
                                        <xsl:when test="not(parent::select/option[@selected]) and position()=1">
                                            true
                                        </xsl:when>
                                        <xsl:otherwise>
                                            false
                                        </xsl:otherwise>
                                    </xsl:choose>
                                    }
                                    <xsl:if test="position()!=last()">,</xsl:if>
                                </xsl:for-each>
                                ]
                                }
                                <xsl:if test="position()!=last()">,</xsl:if>
                            </xsl:when>
                            
                            <!-- text/number fields -->
                            <xsl:otherwise>
                                {
                                "display_name" :
                                        "<xsl:call-template name="post_display_name"><xsl:with-param name="display_name" select="parent::label//preceding-sibling::div//span" /><xsl:with-param name="name" select="@name" /></xsl:call-template>",
                                "name" : "<xsl:value-of select="@name" />",
                                "value" : "<xsl:value-of select="@value"/>",
                                <xsl:if test="@type = 'number'">
                                    "min" : <xsl:choose>
                                        <xsl:when test="@min">
                                            <xsl:value-of select="@min"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            0
                                        </xsl:otherwise>
                                    </xsl:choose>,
                                    "max" : <xsl:choose>
                                        <xsl:when test="@max">
                                            <xsl:value-of select="@max"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            2147483647
                                        </xsl:otherwise>
                                    </xsl:choose>,
                                </xsl:if>
                                 <xsl:if test="@placeholder">
                                    "placeholder": "<xsl:value-of select="@placeholder"/>",
                                 </xsl:if>
                                "type" : <xsl:choose>
                                    <xsl:when test="@type = 'checkbox'">
                                        "<xsl:value-of select="@type"/>",
                                        "is_checked" : <xsl:choose>
                                            <xsl:when test="@checked">
                                                true
                                            </xsl:when>
                                            <xsl:otherwise>
                                                false
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:when>
                                    <xsl:when test="@type">
                                        "<xsl:value-of select="@type"/>"
                                    </xsl:when>
                                    <xsl:otherwise>
                                        "text"
                                    </xsl:otherwise>
                                </xsl:choose>,
                                <xsl:call-template name="post_field_is_error"> <xsl:with-param name="input" select="."/> </xsl:call-template>,
                                <xsl:call-template name="post_field_required"> <xsl:with-param name="input" select="."/> </xsl:call-template>
                                }
                                <xsl:if test="position()!=last()">,</xsl:if>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:for-each>
                    
                    ]
                    }
                </xsl:when>
                
                <!-- helpful details -->
                <xsl:when test="./legend ='helpful details'">
                    <xsl:call-template name="post_helpful_details"></xsl:call-template>
                </xsl:when>

            </xsl:choose>
        </xsl:for-each>
        
    </xsl:template>

</xsl:stylesheet>
