<?xml version="1.0"?>

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:str="http://exslt.org/strings"
    xmlns:exsl="http://exslt.org/common"
    xmlns:regexp="http://exslt.org/regular-expressions"
    extension-element-prefixes="str regexp">
    
    <xsl:import href="tpl_sanitize_6100.xsl" />
    
    <xsl:output method="text"/>
    
    <!--transform CCPostFormData-->
    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="post_login" match="/">
        {
            "is_loggedin" : <xsl:choose>
                <xsl:when test="//header[@class='account-header']//a[contains(@href,'logout')]">
                    true
                </xsl:when>
                <xsl:otherwise>
                    false
                </xsl:otherwise>
            </xsl:choose>,
        
            "action_url" : "<xsl:value-of select="//form[@class='loginform']/@action "/>",
            <xsl:if test="//form/@enctype">
                "enctype": "<xsl:value-of select="//form[@class='loginform']/@enctype "/>",
            </xsl:if>
            "method" : "<xsl:value-of select="//form[@class='loginform']/@method"/>",
            
            <xsl:variable name="loginError" select="//form[@class='loginform']//div[@role='alert']/p" />
            <xsl:if test="$loginError">
                "error": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="$loginError"/></xsl:call-template>",
            </xsl:if>

            <xsl:if test="//div[@class='g-recaptcha']">
                "captcha": {
                    "url": "<xsl:value-of select="//form[@class='loginform']/@action" />",
                    "site": "<xsl:value-of select="//div[@class='g-recaptcha']/@data-sitekey" />",
                    "fields": [
                        { "n": "<xsl:value-of select="//input[@name='n']/@value" />" }
                    ],
                    "token_key": "g-recaptcha-response"
                },
            </xsl:if>

            "message" : "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="//article[@class='page-container']//blockquote/p" /></xsl:call-template>",
            
            "fields" : [
                <xsl:for-each select="//form[@class='loginform']/input[@type='hidden']">
                    {
                        "name" : "<xsl:value-of select="@name" />",
                        "value" : "<xsl:value-of select="@value"/>",
                        "type" : "<xsl:value-of select="@type" />"
                    },
                </xsl:for-each>
                {
                    "name" : "inputEmailHandle",
                    "display_name": "<xsl:value-of select="//form[@class='loginform']//input[@name='inputEmailHandle']//preceding-sibling::label" />",
                    "value" : "<xsl:value-of select="//form[@class='loginform']//input[@name='inputEmailHandle']/@value"/>",
                    "type" : "email",
                    "required": true
                },
                {
                    "name" : "inputPassword",
                    "display_name": "<xsl:value-of select="//form[@class='loginform']//input[@name='inputPassword']//preceding-sibling::label/text()" />",
                    "value" : "<xsl:value-of select="//form[@class='loginform']//input[@name='inputPassword']/@value"/>",
                    "type" : "password",
                    "required": true
                },
                {
                    "name" : "<xsl:value-of select="//form[@class='loginform']//button//@name" />",
                    "value" : "<xsl:value-of select="//form[@class='loginform']//button//@value"/>",
                    "type" : "submit"
                }
            ],
            
            "forms": [
                {
                    "name": "submit",
                    "action_tag": "create_account",
                    "top_title": "<xsl:value-of select="//div[contains(@class,'create-account-box')]//h1[@class='accountform-banner']/text()" />",
                    "action_url" : "<xsl:value-of select="//div[contains(@class,'create-account-box')]//form/@action "/>",
                    <xsl:if test="//div[contains(@class,'create-account-box')]//form/@enctype">
                        "enctype": "<xsl:value-of select="//div[contains(@class,'create-account-box')]//form/@enctype "/>",
                    </xsl:if>
                    "method" : "<xsl:value-of select="//div[contains(@class,'create-account-box')]//form/@method"/>",
                    
                    <xsl:variable name="registerError" select="//div[contains(@class,'create-account-box')]//div[@role='alert']/p" />
                    <xsl:if test="$registerError">
                        "error": "<xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="$registerError"/></xsl:call-template>",
                    </xsl:if>
                    
                    "fields": [
                        <xsl:for-each select="//div[contains(@class,'create-account-box')]//form/input[@type='hidden']">
                            {
                                "name" : "<xsl:value-of select="@name" />",
                                "value" : "<xsl:value-of select="@value"/>",
                                "type" : "<xsl:value-of select="@type" />"
                            },
                        </xsl:for-each>
                        {
                            "name" : "emailAddress",
                            "display_name": "<xsl:value-of select="//div[contains(@class,'create-account-box')]//input[@name='emailAddress']//preceding-sibling::label" />",
                            "value" : "<xsl:value-of select="//div[contains(@class,'create-account-box')]//input[@name='emailAddress']/@value"/>",
                            "type" : "email",
                            "required": true
                        },
                        {
                            "name" : "<xsl:value-of select="//div[contains(@class,'create-account-box')]//button//@name" />",
                            "value" : "<xsl:value-of select="//div[contains(@class,'create-account-box')]//button//@value"/>",
                            "type" : "submit"
                        }
                    ]
                }
                <xsl:if test="//button[@id='onetime']">
                    ,
                    {
                        "name": "submit",
                        "action_url" : "<xsl:value-of select="//button[@id='onetime']/@formaction "/>",
                        "method" : "<xsl:value-of select="//button[@id='onetime']/@formmethod "/>",
                        "action_tag": "one_time_login",
                        "fields" : [
                        <xsl:for-each select="//form[@class='loginform']//input">
                            {
                            "name" : "<xsl:value-of select="@name" />",
                            "value" : "<xsl:value-of select="@value"/>",
                            "type" : "<xsl:value-of select="@type" />"
                            }<xsl:if test="position()!=last()">,</xsl:if>
                        </xsl:for-each>
                        ]
                    }
                </xsl:if>
            ]
        }
    </xsl:template>
    
</xsl:stylesheet>
