<?xml version="1.0"?>

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:str="http://exslt.org/strings"
    xmlns:exsl="http://exslt.org/common"
    xmlns:regexp="http://exslt.org/regular-expressions"
    extension-element-prefixes="str regexp">
    
    <xsl:import href="tpl_sanitize_6100.xsl" />
    
    <xsl:output method="text"/>
    
    <xsl:variable name="upper" select="'ABCDEFGHIJKLMNOPQRSTUVWXYZ'"/>
    <xsl:variable name="lower" select="'abcdefghijklmnopqrstuvwxyz'"/>
    <xsl:variable name="digit" select="'0123456789'"/>
    <xsl:variable name="apos" select="&quot;'&quot;"/>
    <xsl:variable name="alnum" select="concat($upper, $lower, $digit, $apos)"/>
    
    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="post_single_form_definition" match="/">
    
        "action_url" : "<xsl:value-of select="//form/@action "/>",
        <xsl:if test="//form/@enctype">
            "enctype": "<xsl:value-of select="//form/@enctype "/>",
        </xsl:if>
        "method" : "<xsl:value-of select="//form/@method "/>"
    </xsl:template>

<!-- Strips trailing whitespace characters from 'string' -->
<xsl:template name="string-rtrim">
    <xsl:param name="string" />
    <xsl:param name="trim" />

    <xsl:variable name="length" select="string-length($string)" />

    <xsl:if test="$length &gt; 0">
        <xsl:choose>
            <xsl:when test="contains($trim, substring($string, $length, 1))">
                <xsl:call-template name="string-rtrim">
                    <xsl:with-param name="string" select="substring($string, 1, $length - 1)" />
                    <xsl:with-param name="trim"   select="$trim" />
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$string" />
            </xsl:otherwise>
        </xsl:choose>
    </xsl:if>
</xsl:template>

<!-- Strips leading whitespace characters from 'string' -->
<xsl:template name="string-ltrim">
    <xsl:param name="string" />
    <xsl:param name="trim" />

    <xsl:if test="string-length($string) &gt; 0">
        <xsl:choose>
            <xsl:when test="contains($trim, substring($string, 1, 1))">
                <xsl:call-template name="string-ltrim">
                    <xsl:with-param name="string" select="substring($string, 2)" />
                    <xsl:with-param name="trim"   select="$trim" />
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$string" />
            </xsl:otherwise>
        </xsl:choose>
    </xsl:if>
</xsl:template>

<!-- Strips leading and trailing whitespace characters from 'string' -->
<xsl:template name="string-trim">
    <xsl:param name="string" />
    <xsl:param name="trim" />
    <xsl:call-template name="string-rtrim">
        <xsl:with-param name="string">
            <xsl:call-template name="string-ltrim">
                <xsl:with-param name="string" select="$string" />
                <xsl:with-param name="trim"   select="$trim" />
            </xsl:call-template>
        </xsl:with-param>
        <xsl:with-param name="trim"   select="$trim" />
    </xsl:call-template>
</xsl:template>
    
    <xsl:variable name="breadcrumbs">
        <xsl:choose>
            <xsl:when test="//ul[@class='breadcrumbs']">
                <xsl:for-each select="//body/article/header//ul[@class='breadcrumbs'][1]/li/p">
                    <xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="."/></xsl:call-template>
                </xsl:for-each>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="tpl_sanitize">
                    <xsl:with-param name="text" select="//header[@class='global-header']//p"/>
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    
    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="capitalize">
        <!-- Capitalize all the letters in a string -->
        <xsl:param name="s"/>
        <xsl:value-of select="translate($s, $lower, $upper)"/>
    </xsl:template>
    
    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="cap-first">
        <!-- Capitalize the first letter in a string -->
        <xsl:param name="s"/>
        <!-- Use the FP convention of x:xs for recurring on a list -->
        <xsl:variable name="x" select="substring($s, 1, 1)"/>
        <xsl:variable name="xs" select="substring($s, 2)"/>
        <xsl:call-template name="capitalize">
            <xsl:with-param name="s" select="$x"/>
        </xsl:call-template>
        <xsl:value-of select="$xs"/>
    </xsl:template>
    
    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="capitalize-words">
        <!-- Capitalize the first letter of each word as determined by delimiters. -->
        <xsl:param name="delimiters"/>
        <xsl:param name="s"/>
        <xsl:if test="string-length($s)">
            <xsl:choose>
                <xsl:when test="string-length($delimiters)">
                    <!-- Use the FP convention of x:xs for recurring on a list -->
                    <xsl:variable name="d" select="substring($delimiters, 1, 1)"/>
                    <xsl:variable name="ds" select="substring($delimiters, 2)"/>
                    
                    <xsl:call-template name="capitalize-words">
                        <xsl:with-param name="delimiters" select="$ds"/>
                        <xsl:with-param name="s">
                            <!-- substring-before and -after return the empty string if the delimiter isn't in the string -->
                            <xsl:choose>
                                <xsl:when test="contains($s, $d)">
                                    <xsl:value-of select="substring-before($s, $d)"/>
                                    <xsl:value-of select="$d"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="$s"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:with-param>
                    </xsl:call-template>
                    

                    
                    <xsl:call-template name="capitalize-words">
                        <xsl:with-param name="delimiters" select="$ds"/>
                        <xsl:with-param name="s" select="substring-after($s, $d)"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:call-template name="cap-first">
                        <xsl:with-param name="s" select="$s"/>
                    </xsl:call-template>
                    
                    
                </xsl:otherwise>
            </xsl:choose>
        </xsl:if>
    </xsl:template>

    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="post_breadcrumbs" match="/">
        "breadcrumbs" : "<xsl:value-of select="$breadcrumbs"/>"
    </xsl:template>
    
    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="post_display_name">
        <xsl:param name="display_name" />
        <xsl:param name="name" />
        
        <xsl:variable name="sanitized_display_name">
            <xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="$display_name"/></xsl:call-template>
        </xsl:variable>
               
       <xsl:choose>
           <xsl:when test="string-length(str:replace($sanitized_display_name, ' ', '')) > 0">
               <xsl:value-of select="$sanitized_display_name" />
           </xsl:when>
           <xsl:otherwise>
               <xsl:value-of select="str:replace($name, '_', ' ')" />
           </xsl:otherwise>
       </xsl:choose>
       
    </xsl:template>
    
    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="post_input_base_definition">
        <xsl:param name="input" />
        
        "name" : "<xsl:value-of select="$input/@name" />",
        "value" : "<xsl:value-of select="$input/@value"/>",
       
        "autofillable" : <xsl:value-of select="$input/@id='contact_phone' or $input/@id='contact_phone_extension' or $input/@id='contact_name' or $input/@id='GeographicArea' or $input/@id='postal_code' or $input/@name='contact_name' or $input/@name='contact_phone' or $input/@name='contact_phone_extension'"/>,
        
        "type" : <xsl:choose>
            <xsl:when test="$input/@type and $input/@type != 'tel'">
                "<xsl:value-of select="$input/@type" />"
            </xsl:when>
            <xsl:otherwise>
                "text"
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="post_input_number_definition">
        <xsl:param name="input" />
        
        <xsl:call-template name="post_input_base_definition">
            <xsl:with-param name="input" select="$input"/>
        </xsl:call-template>,
        
        "min" : <xsl:choose>
            <xsl:when test="$input/@min">
                <xsl:value-of select="$input/@min"/>
            </xsl:when>
            <xsl:otherwise>
                0
            </xsl:otherwise>
        </xsl:choose>,
        "max" : <xsl:choose>
            <xsl:when test="$input/@max">
                <xsl:value-of select="$input/@max"/>
            </xsl:when>
            <xsl:otherwise>
                2147483647
            </xsl:otherwise>
        </xsl:choose>
        
    </xsl:template>
    
    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="post_input_checkbox_definition">
        <xsl:param name="input" />
        
        <xsl:call-template name="post_input_base_definition">
            <xsl:with-param name="input" select="$input"/>
        </xsl:call-template>,
        
        "is_checked" : <xsl:choose>
            <xsl:when test="$input/@checked">
                true
            </xsl:when>
            <xsl:otherwise>
                false
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    
    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="post_radio_definition" >
        <xsl:param name="radio_x_path" />
        <xsl:param name="radio_names" />
        
        <xsl:for-each select="$radio_x_path">
            {
                "name" : "<xsl:value-of select="./@name"/>",
                "type" : "radio",
                "display_name" : "<xsl:call-template name="post_radio_label_definition"><xsl:with-param name="radio_position" select="position()"/><xsl:with-param name="radio_names" select="$radio_names"/></xsl:call-template>",
                "value" : "<xsl:value-of select="./@value"/>",
                "is_checked" : <xsl:choose>
                    <xsl:when test="@checked">
                        true
                    </xsl:when>
                    <xsl:otherwise>
                        false
                    </xsl:otherwise>
                </xsl:choose>
            }
            <xsl:if test="position()!=last()">,</xsl:if>
        </xsl:for-each>
    </xsl:template>
    
    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="post_radio_label_definition" >
        <xsl:param name="radio_position" />
        <xsl:param name="radio_names" />
        
        <xsl:for-each select="$radio_names">
            <xsl:if test="position() = $radio_position">
                <xsl:call-template name="tpl_sanitize"><xsl:with-param name="text" select="str:replace(.,' [?]','')"/></xsl:call-template>
            </xsl:if>
        </xsl:for-each>
    </xsl:template>

    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="post_field_is_error" >
        <xsl:param name="input" />
        "is_error": <xsl:value-of select="contains($input/parent::label/parent::label/@class, 'err') or contains($input/parent::label/@class, 'err')"/>
    </xsl:template>

    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" name="post_field_required" >
        <xsl:param name="input" />
        "required": <xsl:value-of select="contains($input/parent::label/parent::label/@class, 'req') or contains($input/parent::label/@class, 'req')"/>
    </xsl:template>
    
</xsl:stylesheet>
